@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@
 
 #include <QLineEdit>
 #include <QString>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QDebug>
 
 
@@ -33,7 +33,7 @@ class AnswerBox : public QLineEdit
     Q_OBJECT
 
 public:
-    AnswerBox(QWidget *parent = 0);
+    AnswerBox(QWidget *parent = nullptr);
     ~AnswerBox();
 
     QString normalizeString(QString original);
@@ -46,7 +46,7 @@ signals:
     void answered(bool correct);
 
 private:
-    QString correctAnswer;
+    QString m_correctAnswer;
 
 
 };
