@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -44,20 +44,24 @@
 #include <QTime>
 #include <QKeySequence>
 #include <QLibraryInfo>
+#include <QStandardPaths>   // Qt 6 needs the explicit include
+#include <QRandomGenerator>
 
 #include <QDebug>
 
-// FIXME: unnecessary?
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-#include <phonon/MediaObject>
-#include <phonon/BackendCapabilities>
-#include <phonon/Global>
+#if QT_VERSION_MAJOR == 6
+  #include <phonon4qt6/phonon/MediaObject>
+  #include <phonon4qt6/phonon/AudioOutput>
+  #include <phonon4qt6/phonon/BackendCapabilities>
+  #include <phonon4qt6/phonon/Global>
 #else
-#include <phonon4qt5/phonon/MediaObject>
-#include <phonon4qt5/phonon/BackendCapabilities>
-#include <phonon4qt5/phonon/Global>
+  #include <phonon4qt5/phonon/MediaObject>
+  #include <phonon4qt5/phonon/AudioOutput>
+  #include <phonon4qt5/phonon/BackendCapabilities>
+  #include <phonon4qt5/phonon/Global>
 #endif
 
+
 #include "musicanalyzer.h"
 #include "optionsdialog.h"
 #include "answerbox.h"
@@ -99,8 +103,9 @@ public slots:
 
     void timerTick();
 
-    void updateConfig(bool startGame, QString directory, bool forceReload,
-                      int difficulty, int questions, int players,
+    void updateConfig(bool startGame, QStringList directories,
+                      bool forceReload, int difficulty,
+                      int questions, int players,
                       QStringList playerNameList, bool ownColors);
     void showAbout();
 
@@ -125,28 +130,28 @@ public slots:
     void killRanking();
 
 private:
-    QVBoxLayout *mainLayout;
+    QVBoxLayout *m_mainLayout;
 
-    QWidget *welcomeWidget;
-    QVBoxLayout *welcomeLayout;
-    QLabel *logoLabel;
-    QPushButton *startGameButton;
-    QPushButton *configureButton;
-    QPushButton *aboutButton;
-    QPushButton *quitButton;
-    QAction *quitAction;
-    QTimer *postInitTimer;
-    QTimer *postConfigUpdatedTimer;
+    QWidget *m_welcomeWidget;
+    QVBoxLayout *m_welcomeLayout;
+    QLabel *m_logoLabel;
+    QPushButton *m_startGameButton;
+    QPushButton *m_configureButton;
+    QPushButton *m_aboutButton;
+    QPushButton *m_quitButton;
+    QAction *m_quitAction;
+    QTimer *m_postInitTimer;
+    QTimer *m_postConfigUpdatedTimer;
 
 
-    QWidget *playingWidget;
-    QVBoxLayout *playingLayout;
-    QVBoxLayout *playingTopLayout;
-    QHBoxLayout *playingMiddleLayout;
-    QVBoxLayout *statisticsLayout;
-    QVBoxLayout *answersLayout;
-    QHBoxLayout *playingProgressLayout;
-    QHBoxLayout *playingBottomLayout;
+    QWidget *m_playingWidget;
+    QVBoxLayout *m_playingLayout;
+    QVBoxLayout *m_playingTopLayout;
+    QHBoxLayout *m_playingMiddleLayout;
+    QVBoxLayout *m_statisticsLayout;
+    QVBoxLayout *m_answersLayout;
+    QHBoxLayout *m_playingProgressLayout;
+    QHBoxLayout *m_playingBottomLayout;
 
     QTimer *preQuestionTimer;
     QTimer *postQuestionTimer;
@@ -161,17 +166,17 @@ private:
 
     QLabel *aniNoteLabel;
     QMovie aniNoteMovie;
-    QGroupBox *statisticsBox;
+    QGroupBox *m_statisticsBox;
     QVBoxLayout *statisticsBoxLayout;
-    QLabel *statisticsLabel;
+    QLabel *m_statisticsLabel;
     QTimer *gameTimer;
-    QProgressBar *timeBar;
+    QProgressBar *m_timeBar;
     QProgressBar *gameProgressBar;
     QLabel *gameScoreLabel;
     QLCDNumber *gameScore;
 
-    QLabel *statusLabel;
-    QPushButton *endGameButton;
+    QLabel *m_statusLabel;
+    QPushButton *m_endGameButton;
 
     QPushButton *answerButton[4];
     QAction *answerAction1;
@@ -179,6 +184,7 @@ private:
     QAction *answerAction3;
     QAction *answerAction4;
 
+    Phonon::AudioOutput *musicOutput;
     Phonon::MediaObject *musicPlayer;
 
     OptionsDialog *optionsDialog; // Options (configuration) window
@@ -186,7 +192,7 @@ private:
     MusicAnalyzer *musicAnalyzer;
 
 
-    bool firstRun;
+    bool m_firstRun;
     bool useOwnColorTheme;
 
     bool playing;
@@ -194,21 +200,21 @@ private:
     int difficultyLevel;
     int numQuestions;
     int numPlayers;
-    int currentPlayer;
+    int m_currentPlayer;
 
     QStringList playerNames;
 
-    int maxTime; // depends on difficulty
+    int m_maxTime; // Depends on difficulty
     int warningTime;
     int dangerTime;
 
     int pieceDuration;
 
-    int questionType;
+    int m_questionType;
     int correctAnswer;
 
     int currentMusicFile;
-    QString musicDirectory;
+    QStringList m_musicDirectories;
     QStringList musicFiles[4];
     QString dataDirectory;
 
@@ -220,11 +226,11 @@ private:
     QList<int> score;
 
     // Widget for the "type-the-answer" mode
-    AnswerBox *answerBox;
+    AnswerBox *m_answerBox;
 
     // Ranking window
-    Ranking *ranking;
-    QTimer *rankingTimer;
+    Ranking *m_rankingWindow;
+    QTimer *m_rankingTimer;
 };
 
 
