@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,19 +26,9 @@
 #include "auralwindow.h"
 
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-void customMessageHandlerQt4(QtMsgType type, const char *msg)
-{
-    // do nothing
-    Q_UNUSED(type)
-    Q_UNUSED(msg)
-
-    return;
-}
-#else
-void customMessageHandlerQt5(QtMsgType type,
-                             const QMessageLogContext &context,
-                             const QString &msg)
+void customMessageHandler(QtMsgType type,
+                          const QMessageLogContext &context,
+                          const QString &msg)
 {
     Q_UNUSED(type)
     Q_UNUSED(context)
@@ -48,23 +38,27 @@ void customMessageHandlerQt5(QtMsgType type,
 
     return;
 }
-#endif
+
 
 int main(int argc, char *argv[])
 {
     QApplication auralApp(argc, argv);
 
     auralApp.setApplicationName("Auralquiz");
-    auralApp.setApplicationVersion("1.0.0");
+    auralApp.setApplicationVersion("1.1");
     auralApp.setOrganizationName("JanCoding");
     auralApp.setOrganizationDomain("jancoding.wordpress.com");
+    // This is mainly needed for window managers under Wayland
+    auralApp.setDesktopFileName(QStringLiteral("org.nongnu.auralquiz.desktop"));
 
-    std::cout << QString("Auralquiz v%1 - JanKusanagi 2011-2017\n")
+    std::cout << QString("Auralquiz v%1 - JanKusanagi 2011-2025\n"
+                         "https://jancoding.wordpress.com/auralquiz\n\n")
                  .arg(auralApp.applicationVersion()).toStdString();
-    std::cout << QString("- Built with Qt v%1\n")
-                 .arg(QT_VERSION_STR).toStdString();
-    std::cout << QString("- Running with Qt v%1\n\n")
-                 .arg(qVersion()).toStdString();
+
+    std::cout << QString("- Built with Qt v%1, Phonon v%2\n")
+                 .arg(QT_VERSION_STR).arg(PHONON_VERSION_STR).toStdString();
+    std::cout << QString("- Running with Qt v%1, Phonon v%2\n\n")
+                 .arg(qVersion()).arg(Phonon::phononVersion()).toStdString();
     std::cout.flush();
 
 
@@ -76,12 +70,7 @@ int main(int argc, char *argv[])
     else
     {
         std::cout << "To see debug messages while running, use --debug\n";
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-        qInstallMsgHandler(customMessageHandlerQt4);
-#else
-        qInstallMessageHandler(customMessageHandlerQt5);
-#endif
-
+        qInstallMessageHandler(customMessageHandler);
     }
 
 
