@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,16 +22,14 @@
 #include "musicanalyzer.h"
 
 
-MusicAnalyzer::MusicAnalyzer(QString musicDir,
-                             QString dataDir,
+MusicAnalyzer::MusicAnalyzer(QStringList musicDirectories,
+                             QString dataDirectory,
                              QStringList *musicFiles,
                              QWidget *parent)  :  QWidget(parent)
 {
-    this->musicDirectory = musicDir;
-    this->dataDirectory = dataDir;
-
-    this->musicFiles = musicFiles;
-
+    m_musicDirectories = musicDirectories;
+    m_dataDirectory = dataDirectory;
+    m_musicFiles = musicFiles;
 
     qDebug() << "MusicAnalyzer created";
 }
@@ -44,56 +42,53 @@ MusicAnalyzer::~MusicAnalyzer()
 }
 
 
-void MusicAnalyzer::setMusicDirectory(QString musicDir)
+void MusicAnalyzer::setMusicDirectories(QStringList musicDirectories)
 {
-    this->musicDirectory = musicDir;
+    m_musicDirectories = musicDirectories;
 
-    qDebug() << "MusicAnalyzer: music directory set to " << musicDirectory;
+    qDebug() << "MusicAnalyzer: music directories set to:"
+             << m_musicDirectories;
 }
 
 void MusicAnalyzer::storeMetadataCache()
 {
     // Store info about the scanned music files
-    QFile cachedMetadata0(this->dataDirectory + "/musicFiles0.aq");
+    QFile cachedMetadata0(m_dataDirectory + "/musicFiles0.aq");
     cachedMetadata0.open(QIODevice::WriteOnly);
     QString cachedMetadata0Item;
 
-    QFile cachedMetadata1(this->dataDirectory + "/musicFiles1.aq");
+    QFile cachedMetadata1(m_dataDirectory + "/musicFiles1.aq");
     cachedMetadata1.open(QIODevice::WriteOnly);
     QString cachedMetadata1Item;
 
-    QFile cachedMetadata2(this->dataDirectory + "/musicFiles2.aq");
+    QFile cachedMetadata2(m_dataDirectory + "/musicFiles2.aq");
     cachedMetadata2.open(QIODevice::WriteOnly);
     QString cachedMetadata2Item;
 
-    QFile cachedMetadata3(this->dataDirectory + "/musicFiles3.aq");
+    QFile cachedMetadata3(m_dataDirectory + "/musicFiles3.aq");
     cachedMetadata3.open(QIODevice::WriteOnly);
     QString cachedMetadata3Item;
 
     qDebug() << "Datafiles created";
 
-    for (int counter = 0; counter < this->musicFiles[0].length(); ++counter)
+    for (int counter = 0; counter < m_musicFiles[0].length(); ++counter)
     {
-        // filenames
-        cachedMetadata0Item = musicFiles[0].at(counter);
-        cachedMetadata0Item.append("\n");
+        // Filenames
+        cachedMetadata0Item = m_musicFiles[0].at(counter) + QStringLiteral("\n");
         cachedMetadata0.write(cachedMetadata0Item.toUtf8());
 
         // FIXME: some encoding problems with tags
 
-        // artists
-        cachedMetadata1Item = musicFiles[1].at(counter);
-        cachedMetadata1Item.append("\n");
+        // Artists
+        cachedMetadata1Item = m_musicFiles[1].at(counter) + QStringLiteral("\n");
         cachedMetadata1.write(cachedMetadata1Item.toUtf8());
 
-        // titles
-        cachedMetadata2Item = musicFiles[2].at(counter);
-        cachedMetadata2Item.append("\n");
+        // Titles
+        cachedMetadata2Item = m_musicFiles[2].at(counter) + QStringLiteral("\n");
         cachedMetadata2.write(cachedMetadata2Item.toUtf8());
 
-        // albums
-        cachedMetadata3Item = musicFiles[3].at(counter);
-        cachedMetadata3Item.append("\n");
+        // Albums
+        cachedMetadata3Item = m_musicFiles[3].at(counter) + QStringLiteral("\n");
         cachedMetadata3.write(cachedMetadata3Item.toUtf8());
     }
 
@@ -120,24 +115,26 @@ void MusicAnalyzer::storeMetadataCache()
 void MusicAnalyzer::loadSongList()
 {
     qDebug() << "MusicAnalyzer::loadSongList()";
-    if (this->musicDirectory.isEmpty())
+    if (m_musicDirectories.isEmpty())  // WIP FIXME
     {
-        emit setStartGameButton(false, tr("Configure your music folder"), "");
+        emit setStartGameButton(false,
+                                tr("Configure your music folder"),
+                                QString());
         qDebug() << "Music directory not configured, aborting scan";
 
         return;
     }
 
-    QFile cachedMetaData0(this->dataDirectory + "/musicFiles0.aq");
+    QFile cachedMetaData0(m_dataDirectory + "/musicFiles0.aq");
     cachedMetaData0.open(QIODevice::ReadOnly);
 
-    QFile cachedMetaData1(this->dataDirectory + "/musicFiles1.aq");
+    QFile cachedMetaData1(m_dataDirectory + "/musicFiles1.aq");
     cachedMetaData1.open(QIODevice::ReadOnly);
 
-    QFile cachedMetaData2(this->dataDirectory + "/musicFiles2.aq");
+    QFile cachedMetaData2(m_dataDirectory + "/musicFiles2.aq");
     cachedMetaData2.open(QIODevice::ReadOnly);
 
-    QFile cachedMetaData3(this->dataDirectory + "/musicFiles3.aq");
+    QFile cachedMetaData3(m_dataDirectory + "/musicFiles3.aq");
     cachedMetaData3.open(QIODevice::ReadOnly);
 
 
@@ -155,10 +152,10 @@ void MusicAnalyzer::loadSongList()
         return;
     }
 
-    this->musicFiles[0].clear();
-    this->musicFiles[1].clear();
-    this->musicFiles[2].clear();
-    this->musicFiles[3].clear();
+    m_musicFiles[0].clear();
+    m_musicFiles[1].clear();
+    m_musicFiles[2].clear();
+    m_musicFiles[3].clear();
 
     /*
      * FIXME: PLENTY OF ERROR CONTROL MISSING HERE
@@ -174,17 +171,17 @@ void MusicAnalyzer::loadSongList()
     {
         // FIXME: separate this mess (avoids encoding problems)
         fileName = QString::fromUtf8(cachedMetaData0.readLine(1024).trimmed().data());
-        musicFiles[0].append(fileName);
+        m_musicFiles[0].append(fileName);
 
         // FIXME: assuming Utf8 in artist and title tags, for now
         artistName = QString::fromUtf8(cachedMetaData1.readLine(1024).trimmed().data());
-        musicFiles[1].append(artistName);
+        m_musicFiles[1].append(artistName);
 
         songTitle = QString::fromUtf8(cachedMetaData2.readLine(1024).trimmed().data());
-        musicFiles[2].append(songTitle);
+        m_musicFiles[2].append(songTitle);
 
         albumTitle = QString::fromUtf8(cachedMetaData3.readLine(1024).trimmed().data());
-        musicFiles[3].append(albumTitle);
+        m_musicFiles[3].append(albumTitle);
     }
 
     cachedMetaData0.close();
@@ -192,7 +189,7 @@ void MusicAnalyzer::loadSongList()
     cachedMetaData2.close();
     cachedMetaData3.close();
 
-    emit setStartGameButton(true, "", "");
+    emit setStartGameButton(true, QString(), QString());
 
 
     qDebug() << "loadSongList() done";
@@ -209,23 +206,30 @@ void MusicAnalyzer::loadSongList()
 void MusicAnalyzer::createSongList()
 {
     qDebug() << "MusicAnalyzer::createSongList()";
+    if (m_musicDirectories.isEmpty())
+    {
+        qDebug() << "Nothing to scan!";
+        return;
+    }
 
+    emit setStartGameButton(false,
+                            tr("Analyzing music. Please wait"),
+                            QString());
 
-    emit setStartGameButton(false, tr("Analyzing music. Please wait"), "");
-
-    this->musicFiles[0].clear(); // make file-list empty
-    this->musicFiles[1].clear(); // make artists-list empty
-    this->musicFiles[2].clear(); // make titles-list empty
-    this->musicFiles[3].clear(); // make albums-list empty
+    m_musicFiles[0].clear();  // Make file-list empty
+    m_musicFiles[1].clear();  // Make artists-list empty
+    m_musicFiles[2].clear();  // Make titles-list empty
+    m_musicFiles[3].clear();  // Make albums-list empty
 
 
 
-    QProgressDialog fileListerProgressDialog(tr("Getting list of files under\n"
-                                                "%1",
-                                                "%1 is a folder")
-                                           .arg(musicDirectory),
-                                           tr("Cancel"),
-                                           0, 10000,
+    QProgressDialog fileListerProgressDialog(tr("Getting list of files under:",
+                                                "A list of folders is shown below")
+                                             + "\n\n"
+                                             + m_musicDirectories.join(",\n")
+                                             + "\n",
+                                             tr("Cancel"),
+                                             0, 2000, // Initially expect up to 2000 files
                                              this);
     fileListerProgressDialog.setWindowTitle(tr("Listing files...")
                                             + " - Auralquiz");
@@ -233,45 +237,60 @@ void MusicAnalyzer::createSongList()
     fileListerProgressDialog.setMinimumDuration(0);
     fileListerProgressDialog.show();
 
+
     QStringList directoryFiles;
 
-    qDebug() << "Listing files under" << musicDirectory;
-    QDirIterator dirList(QDir(this->musicDirectory,
-                              "*.mp3 *.ogg *.oga *.flac *.opus",
-                              QDir::NoSort, QDir::Files),
-                         QDirIterator::Subdirectories | QDirIterator::FollowSymlinks);
+    qDebug() << "Listing files under" << m_musicDirectories;
 
-    while (dirList.hasNext())
+    foreach (QString directory, m_musicDirectories)
     {
-        directoryFiles.append(dirList.next());
+        qDebug() << "Directory:" << directory;
 
-        // update progressbar
-        fileListerProgressDialog.setValue(directoryFiles.length());
-        qApp->processEvents();
-        if (fileListerProgressDialog.wasCanceled())
+        QDirIterator dirList(QDir(directory,
+                                  "*.mp3 *.ogg *.oga *.flac *.opus",
+                                  QDir::NoSort, QDir::Files),
+                             QDirIterator::Subdirectories
+                             | QDirIterator::FollowSymlinks);
+
+        while (dirList.hasNext())
         {
-            qDebug() << "createSongList(): file listing cancelled by button";
-            emit setStartGameButton(false,
-                                    tr("Please reload music info"),
-                                    tr("Music analysis was cancelled"));
+            directoryFiles.append(dirList.next());
 
-            fileListerProgressDialog.reset();
-            return; // you sure?
+            // Update progressbar
+            const int fileCount = directoryFiles.length();
+
+            fileListerProgressDialog.setValue(fileCount);
+            if (fileCount >= fileListerProgressDialog.maximum() - 10)
+            {
+                // There are more than 2000 files, readjust progressbar's max
+                fileListerProgressDialog.setMaximum(fileCount * 2);
+            }
+            qApp->processEvents();
+
+            if (fileListerProgressDialog.wasCanceled())
+            {
+                qDebug() << "File listing cancelled by button";
+                emit setStartGameButton(false,
+                                        tr("Please reload music info"),
+                                        tr("Music analysis was cancelled"));
+
+                fileListerProgressDialog.reset();
+                return; // you sure?
+            }
         }
-
     }
-    fileListerProgressDialog.close();
 
+    fileListerProgressDialog.close();
 
     if (directoryFiles.length() == 0)
     {
         qDebug() << "There are no files!";
-        QString errorExplanation = tr("There are no valid music files "
-                                      "in your selected music directory.")
-                                   + "\n"
-                                   + tr("Please, select another directory "
-                                        "containing Ogg, FLAC or MP3 files, "
-                                        "and try again.");
+        const QString errorExplanation = tr("There are no valid music files "
+                                            "in your selected music folders.")
+                                         + "\n"
+                                         + tr("Please, select other folders "
+                                              "containing Ogg, FLAC, Opus "
+                                              "or MP3 files, and try again.");
         QMessageBox::critical(this,
                               tr("There is no music!"),
                               errorExplanation);
@@ -284,16 +303,19 @@ void MusicAnalyzer::createSongList()
     }
 
 
-    // Start analyzer loop
-    int validFiles = 0;
-    int totalFiles = directoryFiles.length();
+    /////////////////////////// Start analyzer loop ///////////////////////////
 
-    QString totalFilesString = QLocale::system().toString(totalFiles);
-    QProgressDialog analyzerProgressDialog(tr("Analyzing %1 files\n"
-                                              "under %2",
-                                              "%1 is a number, %2 is a folder")
+    int validFiles = 0;
+    const int totalFiles = directoryFiles.length();
+    const QString totalFilesString = QLocale::system().toString(totalFiles);
+
+    QProgressDialog analyzerProgressDialog(tr("Analyzing %1 files under:",
+                                              "%1 is a number, and a folder "
+                                              "list follows below")
                                            .arg(totalFilesString)
-                                           .arg(musicDirectory),
+                                           + "\n\n"
+                                           + m_musicDirectories.join(",\n")
+                                           + "\n",
                                            tr("Cancel analysis"),
                                            0, totalFiles,
                                            this);
@@ -301,6 +323,7 @@ void MusicAnalyzer::createSongList()
                                           + " - Auralquiz");
     analyzerProgressDialog.setMinimumWidth(400);
     analyzerProgressDialog.setMinimumDuration(0); // Always show
+    analyzerProgressDialog.setWindowModality(Qt::ApplicationModal);
 
 
     for (int currentFile = 0; currentFile != totalFiles; ++currentFile)
@@ -334,11 +357,11 @@ void MusicAnalyzer::createSongList()
         {
             qDebug() << "Has artist AND title, OK ->" << artistTag << titleTag;
             qDebug() << "Album, if any            ->" << albumTag;
-            this->musicFiles[0].append(directoryFiles.at(currentFile));
+            m_musicFiles[0].append(directoryFiles.at(currentFile));
 
-            this->musicFiles[1].append(artistTag);
-            this->musicFiles[2].append(titleTag);
-            this->musicFiles[3].append(albumTag);
+            m_musicFiles[1].append(artistTag);
+            m_musicFiles[2].append(titleTag);
+            m_musicFiles[3].append(albumTag);
 
             ++validFiles;
         }
@@ -348,31 +371,34 @@ void MusicAnalyzer::createSongList()
                         "or a related error occurred";
         }
 
-        analyzerProgressDialog.setValue(currentFile); // update progressbar
+        analyzerProgressDialog.setValue(currentFile); // Update progressbar
         qApp->processEvents();
+
         if (analyzerProgressDialog.wasCanceled())
         {
             qDebug() << "createSongList(): analysis cancelled by button";
-            musicFiles[0].clear();
-            musicFiles[1].clear();
-            musicFiles[2].clear();
-            musicFiles[3].clear();
+            m_musicFiles[0].clear();
+            m_musicFiles[1].clear();
+            m_musicFiles[2].clear();
+            m_musicFiles[3].clear();
 
-            emit setStartGameButton(false, tr("Please reload music info"), "");
+            emit setStartGameButton(false,
+                                    tr("Please reload music info"),
+                                    QString());
 
             return; // you sure?
         }
 
-    } // end analyzer loop
+    } ///////////////////////// End analyzer loop /////////////////////////////
 
 
 
     // We're done scanning
 
     qDebug() << "\n\n---------------- SCAN COMPLETE -------";
-    //memory required for the lists?
-    qDebug() << "memory used, about: "<< musicFiles[0].length()*40*4 << "bytes";
-    qDebug() << "Storing data in:" << this->dataDirectory;
+    // Memory required for the lists?
+    qDebug() << "memory used, about: "<< m_musicFiles[0].length()*40*4 << "bytes";
+    qDebug() << "Storing data in:" << m_dataDirectory;
     qDebug() << "Valid files:" << validFiles;
 
 
@@ -393,7 +419,7 @@ void MusicAnalyzer::createSongList()
     this->storeMetadataCache();
 
     // songlist is ready, allow starting game
-    emit setStartGameButton(true, tr("&Start game"), "");
+    emit setStartGameButton(true, tr("&Start game"), QString());
 
 
     qDebug() << "start button re-enabled and with focus";
