@@ -1,6 +1,6 @@
 /*
  *   This file is part of Auralquiz
- *   Copyright 2011-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2011-2025  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 
 /*
- *   Constructor, called on startup even if options dialog is never shown
+ * Constructor, called on startup even if options dialog is never shown
  *
  */
 OptionsDialog::OptionsDialog(QWidget *parent) : QWidget(parent)
@@ -40,37 +40,57 @@ OptionsDialog::OptionsDialog(QWidget *parent) : QWidget(parent)
 
     playMode = false;
 
+    QStringList defaultMusicDirectories;
+    defaultMusicDirectories = QStandardPaths::standardLocations(QStandardPaths::MusicLocation);
+
+    // If MusicLocation is the same as HOME, don't use it.
+    if (isHomeInScanDirectories(defaultMusicDirectories))
+    {
+        defaultMusicDirectories.clear();
+    }
+
+    m_musicDirectories = settings.value("musicDirectories",
+                                        defaultMusicDirectories).toStringList();
+    m_musicDirectories = this->cleanupDirectoryList(m_musicDirectories);
+    qDebug() << "Music directories:" << m_musicDirectories;
 
-    // FIXME: check if musicdir == home, here too
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    this->musicDirectory = settings.value("musicDirectory",
-                                          QDesktopServices::storageLocation(QDesktopServices::MusicLocation)).toString();
-#else
-    this->musicDirectory = settings.value("musicDirectory",
-                                          QStandardPaths::standardLocations(QStandardPaths::MusicLocation)
-                                          .first())
-                                   .toString();
-#endif
 
     this->reload = false;
 
 
     // TOP layout
-    musicFromLabel = new QLabel(tr("Using music from:") + " ", this);
+    musicFromLabel = new QLabel(tr("Using music from:") + QStringLiteral(" "),
+                                this);
 
-    currentMusicDirectoryLabel = new QLabel(this->musicDirectory, this);
+    m_directoriesListWidget = new QListWidget(this);
+    m_directoriesListWidget->setDragDropMode(QAbstractItemView::InternalMove);
+    m_directoriesListWidget->addItems(m_musicDirectories);
 
-    selectMusicDirectoryButton = new QPushButton(QIcon::fromTheme("folder-sound"),
-                                                 tr("Select your &music folder..."),
-                                                 this);
-    connect(selectMusicDirectoryButton, SIGNAL(clicked()),
-            this, SLOT(selectMusicDirectory()));
+    m_addDirectoryButton = new QPushButton(QIcon::fromTheme("folder-sound"),
+                                           tr("Add a music folder..."),
+                                           this);
+    connect(m_addDirectoryButton, &QAbstractButton::clicked,
+            this, &OptionsDialog::addMusicDirectory);
+
+    m_removeDirectoryButton = new QPushButton(QIcon::fromTheme("edit-delete"),
+                                              tr("Remove selected folder"),
+                                              this);
+    m_removeDirectoryButton->setDisabled(m_musicDirectories.isEmpty());
+    connect(m_removeDirectoryButton, &QAbstractButton::clicked,
+            this, &OptionsDialog::removeSelectedMusicDirectory);
+
+    m_topRightLayout = new QVBoxLayout();
+    m_topRightLayout->addWidget(m_addDirectoryButton,    0, Qt::AlignTop);
+    m_topRightLayout->addWidget(m_removeDirectoryButton, 0, Qt::AlignBottom);
 
     topLayout = new QHBoxLayout();
-    topLayout->addWidget(musicFromLabel);
-    topLayout->addWidget(currentMusicDirectoryLabel);
-    topLayout->addSpacing(16);
-    topLayout->addWidget(selectMusicDirectoryButton);
+    topLayout->addWidget(musicFromLabel, 0, Qt::AlignTop);
+    topLayout->addWidget(m_directoriesListWidget);
+    topLayout->addLayout(m_topRightLayout);
+
+    m_separatorFrame = new QFrame(this);
+    m_separatorFrame->setFrameShape(QFrame::HLine);
+    m_separatorFrame->setMinimumHeight(48);
 
 
     // MIDDLE layout
@@ -81,7 +101,6 @@ OptionsDialog::OptionsDialog(QWidget *parent) : QWidget(parent)
 
     //// difficulty sub-layout
     difficultyEasy = new QPushButton("< " + tr("&Easier"), this);
-    //difficultyEasy->setFlat(true);
     connect(difficultyEasy, SIGNAL(clicked()),
             this, SLOT(setDifficultyEasier()));
     difficultyTopLayout->addWidget(difficultyEasy);
@@ -96,7 +115,6 @@ OptionsDialog::OptionsDialog(QWidget *parent) : QWidget(parent)
     difficultyTopLayout->addWidget(difficultyLevel);
 
     difficultyHard = new QPushButton(tr("&Harder") + " >", this);
-    //difficultyHard->setFlat(true);
     difficultyTopLayout->addWidget(difficultyHard);
     connect(difficultyHard, SIGNAL(clicked()),
             this, SLOT(setDifficultyHarder()));
@@ -253,11 +271,11 @@ OptionsDialog::OptionsDialog(QWidget *parent) : QWidget(parent)
 
     mainLayout = new QVBoxLayout();
     mainLayout->addLayout(topLayout);
-    mainLayout->addStretch(1);
+    mainLayout->addWidget(m_separatorFrame);
     mainLayout->addLayout(middleLayout);
-    mainLayout->addStretch(2);
+    mainLayout->addSpacing(8);
     mainLayout->addWidget(playerNamesGroup);
-    mainLayout->addStretch(3);
+    mainLayout->addStretch(0);
     mainLayout->addLayout(bottomLayout);
     this->setLayout(mainLayout);
 
@@ -272,6 +290,55 @@ OptionsDialog::~OptionsDialog()
 }
 
 
+bool OptionsDialog::isHomeInScanDirectories(QStringList directories)
+{
+    foreach (QString directory, directories)
+    {
+        if (QStandardPaths::standardLocations(QStandardPaths::HomeLocation)
+                           .contains(directory))
+        {
+            return true;
+        }
+    }
+
+    return false;
+}
+
+
+QStringList OptionsDialog::cleanupDirectoryList(QStringList directories)
+{
+    QStringList newList;
+
+    foreach (QString directory, directories)
+    {
+        QString newDirectory = directory.trimmed();
+
+        if (!newDirectory.isEmpty())
+        {
+            // Ensure path ends with /
+            if (!newDirectory.endsWith(QStringLiteral("/")))
+            {
+                newDirectory.append(QStringLiteral("/"));
+            }
+
+            // Avoid having duplicate entries
+            if (!newList.contains(newDirectory))
+            {
+                newList.append(newDirectory);
+            }
+        }
+    }
+
+    return newList;
+}
+
+
+QStringList OptionsDialog::getMusicDirectories()
+{
+    return m_musicDirectories;
+}
+
+
 void OptionsDialog::showEvent(QShowEvent *event)
 {
     this->reload = false; // make forceReload false again
@@ -294,26 +361,71 @@ void OptionsDialog::closeEvent(QCloseEvent *event)
 
 
 /*
- *   Open dialog to select directory where music is located
+ * Open dialog to select a directory, to add to the list of directories
+ * to scan for music
  *
  */
-void OptionsDialog::selectMusicDirectory()
+void OptionsDialog::addMusicDirectory()
 {
+    QString initialDirectory;
+    if (!m_musicDirectories.isEmpty())
+    {
+        initialDirectory = m_musicDirectories.last();
+    }
+    else
+    {
+        initialDirectory = QStandardPaths::standardLocations(QStandardPaths::MusicLocation)
+                                          .first();
+    }
+
     QString newMusicDir;
     newMusicDir = QFileDialog::getExistingDirectory(this,
-                                                    tr("Select where your music is located"),
-                                                    this->musicDirectory,
+                                                    tr("Select where your "
+                                                       "music is located"),
+                                                    initialDirectory,
                                                     QFileDialog::ShowDirsOnly);
-    if (!newMusicDir.isEmpty()) // if user DID NOT cancel the "select directory" dialog
+
+    if (!newMusicDir.isEmpty()) // User DID NOT cancel the "select directory" dialog
     {
-        musicDirectory = newMusicDir;
-        if (!musicDirectory.endsWith("/"))
+        if (QDir(newMusicDir).isReadable())
         {
-            // Adding final "/" if it's not present in chosen path
-            musicDirectory.append("/");
+            if (!newMusicDir.endsWith("/"))
+            {
+                // Adding final "/" if it's not present in chosen path
+                newMusicDir.append("/");
+            }
+
+            m_directoriesListWidget->addItem(newMusicDir);
+            m_directoriesListWidget->setCurrentRow(m_directoriesListWidget->count()
+                                                   - 1);
+            m_removeDirectoryButton->setEnabled(true);
+        }
+        else
+        {
+            QMessageBox::critical(this,
+                                  tr("Error"),
+                                  tr("Cannot enter selected folder:")
+                                  + "\n"
+                                  + newMusicDir
+                                  + "\n\n"
+                                  + tr("Please choose another one.",
+                                       "As in: another folder"));
+            qDebug() << "Cannot enter directory:" << newMusicDir;
+        }
+    }
+}
+
+
+void OptionsDialog::removeSelectedMusicDirectory()
+{
+    const int currentDirectoryRow = m_directoriesListWidget->currentRow();
+    if (currentDirectoryRow != -1)
+    {
+        delete m_directoriesListWidget->item(currentDirectoryRow);
+        if (m_directoriesListWidget->count() == 0)
+        {
+            m_removeDirectoryButton->setDisabled(true);
         }
-        // update label indicating current path for music
-        currentMusicDirectoryLabel->setText(this->musicDirectory);
     }
 }
 
@@ -404,17 +516,15 @@ void OptionsDialog::saveOptions()
     }
 
 
-
-    // FIXME: this IF code is duplicated 3 times
-    if (!musicDirectory.endsWith("/"))
+    m_musicDirectories.clear();
+    // Generate directory list from the QListWidget
+    for (int count = 0; count != m_directoriesListWidget->count(); ++count)
     {
-        // Adding final "/" if it's not present in chosen path
-        musicDirectory.append("/");
+        m_musicDirectories.append(m_directoriesListWidget->item(count)->text());
     }
 
-
     emit optionsChanged(this->playMode,
-                        this->musicDirectory,
+                        m_musicDirectories,
                         this->reload,
                         this->difficultyLevel->value(),
                         this->numQuestions->value(),
@@ -447,8 +557,11 @@ void OptionsDialog::showConfigMode()
     playMode = false;
 
     this->musicFromLabel->show();
-    this->currentMusicDirectoryLabel->show();
-    this->selectMusicDirectoryButton->show();
+    m_directoriesListWidget->show();
+    m_addDirectoryButton->show();
+    m_removeDirectoryButton->show();
+    m_separatorFrame->show();
+
     this->reloadMusicInfoButton->show();
 
     this->useOwnColors->show();
@@ -477,8 +590,11 @@ void OptionsDialog::showPlayMode()
     playMode = true;
 
     this->musicFromLabel->hide();
-    this->currentMusicDirectoryLabel->hide();
-    this->selectMusicDirectoryButton->hide();
+    m_directoriesListWidget->hide();
+    m_addDirectoryButton->hide();
+    m_removeDirectoryButton->hide();
+    m_separatorFrame->hide();
+
     this->reloadMusicInfoButton->hide();
 
     this->useOwnColors->hide();
