@@ -4,7 +4,7 @@
 <context>
     <name>AnswerBox</name>
     <message>
-        <location filename="../src/answerbox.cpp" line="29"/>
+        <location filename="../src/answerbox.cpp" line="30"/>
         <source>Type the answer here</source>
         <translation>Zde napište odpověď</translation>
     </message>
@@ -17,150 +17,150 @@
         <translation>První použití</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="264"/>
+        <location filename="../src/auralwindow.cpp" line="220"/>
         <source>Good</source>
         <translation>Dobrý</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="273"/>
+        <location filename="../src/auralwindow.cpp" line="229"/>
         <source>Bad</source>
         <translation>Špatný</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="282"/>
+        <location filename="../src/auralwindow.cpp" line="238"/>
         <source>Timed out</source>
         <translation>Přestávka</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="312"/>
+        <location filename="../src/auralwindow.cpp" line="269"/>
         <source>&amp;Start game</source>
         <translation>&amp;Spustit hru</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="321"/>
+        <location filename="../src/auralwindow.cpp" line="278"/>
         <source>&amp;Options</source>
         <translation>&amp;Volby</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="328"/>
+        <location filename="../src/auralwindow.cpp" line="285"/>
         <source>&amp;About...</source>
         <translation>&amp;O...</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="334"/>
+        <location filename="../src/auralwindow.cpp" line="291"/>
         <source>&amp;Quit</source>
         <translation>&amp;Ukončit</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="427"/>
+        <location filename="../src/auralwindow.cpp" line="384"/>
         <source>Time</source>
         <translation>Čas</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="430"/>
+        <location filename="../src/auralwindow.cpp" line="387"/>
         <source>Remaining time to answer this question</source>
         <translation>Čas zbývající na zodpovězení této otázky</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="434"/>
+        <location filename="../src/auralwindow.cpp" line="391"/>
         <source>%v out of %m questions - %p%</source>
         <translation>%v z %m otázek - %p%</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="437"/>
+        <location filename="../src/auralwindow.cpp" line="394"/>
         <source>How many questions you&apos;ve answered</source>
         <translation>Kolik otázek jste zodpověděl</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="439"/>
+        <location filename="../src/auralwindow.cpp" line="396"/>
         <source>Score</source>
         <translation>Výsledek</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="446"/>
+        <location filename="../src/auralwindow.cpp" line="403"/>
         <source>Your current score</source>
         <translation>Váš nynější výsledek</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="454"/>
+        <location filename="../src/auralwindow.cpp" line="411"/>
         <source>&amp;End game</source>
         <translation>&amp;Ukončit hru</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="482"/>
+        <location filename="../src/auralwindow.cpp" line="439"/>
         <source>Statistics</source>
         <translation>Statistika</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="664"/>
+        <location filename="../src/auralwindow.cpp" line="622"/>
         <source>Sound system error</source>
         <translation>Chyba zvukového systému</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="665"/>
+        <location filename="../src/auralwindow.cpp" line="623"/>
         <source>There seems to be a problem with your sound system.</source>
         <translation>Zdá se, že váš zvukový systém má potíže.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1122"/>
+        <location filename="../src/auralwindow.cpp" line="1088"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
         <translatorcomment>(note by Jan: This should read &apos;Czech translation by YourName&apos; ;)</translatorcomment>
         <translation>Překlad do češtiny: Pavel Fric.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1133"/>
+        <location filename="../src/auralwindow.cpp" line="1098"/>
         <source>Auralquiz is licensed under the GNU GPL license.</source>
         <translation>Auralquiz je licencován pod licencí GNU GPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1135"/>
+        <location filename="../src/auralwindow.cpp" line="1100"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
         <translation>Obrázek na hlavní obrazovce a některé ikony založen na ikonách Oxygen vydaných pod licencí LGPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1373"/>
+        <location filename="../src/auralwindow.cpp" line="1351"/>
         <source>Go, %1!</source>
         <comment>%1=player&apos;s name</comment>
         <translation>Jdi, %1!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1501"/>
+        <location filename="../src/auralwindow.cpp" line="1479"/>
         <source>Correct answer was:</source>
         <translation>Správná odpověď byla:</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1572"/>
+        <location filename="../src/auralwindow.cpp" line="1550"/>
         <source>End game?</source>
         <translation>Ukončit hru?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1573"/>
+        <location filename="../src/auralwindow.cpp" line="1551"/>
         <source>Are you sure you want to end this game?</source>
         <translation>Opravdu chcete tuto hru ukončit?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;Yes, end it</source>
         <translation>&amp;Ano, ukončit</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;No</source>
         <translation>&amp;Ne</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1208"/>
+        <location filename="../src/auralwindow.cpp" line="1185"/>
         <source>Player %1 of %2</source>
         <translation>Hráč %1 z %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="944"/>
+        <location filename="../src/auralwindow.cpp" line="901"/>
         <source>Error playing sound</source>
         <translation>Chyba při přehrávání zvuku</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="945"/>
+        <location filename="../src/auralwindow.cpp" line="902"/>
         <source>An error occurred while playing sound.
 The error message was: %1
 
@@ -171,17 +171,17 @@ Chybové hlášení bylo: %1
 Možná vaše jádro Phonon nemá podporu pro formát MP3.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1030"/>
+        <location filename="../src/auralwindow.cpp" line="997"/>
         <source>Time&apos;s up!!</source>
         <translation>Čas vypršel!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1106"/>
+        <location filename="../src/auralwindow.cpp" line="1074"/>
         <source>About Auralquiz</source>
         <translation>O programu Auralquiz</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1117"/>
+        <location filename="../src/auralwindow.cpp" line="1084"/>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz nahrává všechnu vaši hudbu ze zadané složky a ptá se na ni přehrávaje kousek z každého hudebního souboru jako nápovědu.</translation>
     </message>
@@ -207,135 +207,135 @@ Aby hra běžela správně, je potřeba, aby soubory byly řádně označkovány
 Prohlídka může chvíli trvat a program nebude odpovídat, dokud nebude hotová. Mějte, prosím, trpělivost.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="668"/>
+        <location filename="../src/auralwindow.cpp" line="626"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
         <translation>Může být, že nemáte nainstalovánu podpůrnou vrstvu Phonon.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="777"/>
+        <location filename="../src/auralwindow.cpp" line="736"/>
         <source>Starting!</source>
         <translation>Začínáme!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="778"/>
+        <location filename="../src/auralwindow.cpp" line="737"/>
         <source>Let&apos;s go!</source>
         <translation>Pojďme na to!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="779"/>
+        <location filename="../src/auralwindow.cpp" line="738"/>
         <source>GO!!</source>
         <translation>Pojďme!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="780"/>
+        <location filename="../src/auralwindow.cpp" line="739"/>
         <source>Good luck!</source>
         <translation>Hodně štěstí!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="790"/>
+        <location filename="../src/auralwindow.cpp" line="749"/>
         <source>%1 songs available</source>
         <translation>Dostupných %1 písní</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1031"/>
+        <location filename="../src/auralwindow.cpp" line="998"/>
         <source>The answer was:</source>
         <translation>Odpověď byla:</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1129"/>
+        <location filename="../src/auralwindow.cpp" line="1095"/>
         <source>Thanks to all the testers, translators and packagers, who help make Auralquiz better!</source>
         <translation>Poděkování všem zkoušečům, překladatelům a balíčkářům, kteří Auralquiz pomohli udělat lepším!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1198"/>
+        <location filename="../src/auralwindow.cpp" line="1172"/>
         <source>Who plays this song?</source>
         <translation>Kdo hraje tuto píseň?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1202"/>
+        <location filename="../src/auralwindow.cpp" line="1176"/>
         <source>What&apos;s the title of this song?</source>
         <translation>Jaký je název této písně?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1319"/>
+        <location filename="../src/auralwindow.cpp" line="1297"/>
         <source>Not enough music files</source>
         <translation>Nedostatek hudebních souborů</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1320"/>
+        <location filename="../src/auralwindow.cpp" line="1298"/>
         <source>You don&apos;t have enough music files, or from enough different artists.
 You need music from at least 5 different artists to be able to generate questions.</source>
         <translation>Nemáte dostatek hudebních souborů, nebo dost souborů od různých umělců.
 Na tvoření otázek potřebujete hudbu od alespoň pěti různých umělců.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1379"/>
+        <location filename="../src/auralwindow.cpp" line="1357"/>
         <source>Next!</source>
         <translation>Další</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1454"/>
+        <location filename="../src/auralwindow.cpp" line="1432"/>
         <source>Correct!!</source>
         <translation>Správně!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1455"/>
+        <location filename="../src/auralwindow.cpp" line="1433"/>
         <source>Yeah!</source>
         <translation>Ano!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1456"/>
+        <location filename="../src/auralwindow.cpp" line="1434"/>
         <source>That&apos;s right!</source>
         <translation>Správně!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1457"/>
+        <location filename="../src/auralwindow.cpp" line="1435"/>
         <source>Good!</source>
         <translation>Dobře!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1458"/>
+        <location filename="../src/auralwindow.cpp" line="1436"/>
         <source>Great!</source>
         <translation>Báječně!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1470"/>
+        <location filename="../src/auralwindow.cpp" line="1448"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
         <translation>%1 od %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1475"/>
+        <location filename="../src/auralwindow.cpp" line="1453"/>
         <source>+%1 points!</source>
         <translation>+%1 bodů!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1486"/>
+        <location filename="../src/auralwindow.cpp" line="1464"/>
         <source>Wrong!</source>
         <translation>Špatně!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1487"/>
+        <location filename="../src/auralwindow.cpp" line="1465"/>
         <source>No!</source>
         <translation>Ne!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1488"/>
+        <location filename="../src/auralwindow.cpp" line="1466"/>
         <source>That&apos;s not it.</source>
         <translation>To není ono.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1489"/>
+        <location filename="../src/auralwindow.cpp" line="1467"/>
         <source>Ooops!</source>
         <translation>Jejda!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1490"/>
+        <location filename="../src/auralwindow.cpp" line="1468"/>
         <source>FAIL!</source>
         <translation>Neúspěch!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1408"/>
+        <location filename="../src/auralwindow.cpp" line="1386"/>
         <source>All done!</source>
         <translation>Vše hotovo!</translation>
     </message>
@@ -343,90 +343,108 @@ Na tvoření otázek potřebujete hudbu od alespoň pěti různých umělců.</t
 <context>
     <name>MusicAnalyzer</name>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="125"/>
+        <location filename="../src/musicanalyzer.cpp" line="121"/>
         <source>Configure your music folder</source>
         <translation>Nastavte složku s hudbou</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="214"/>
+        <location filename="../src/musicanalyzer.cpp" line="216"/>
         <source>Analyzing music. Please wait</source>
         <translation>Provádí se rozbor hudby. Počkejte, prosím</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="223"/>
         <source>Getting list of files under
 %1</source>
         <comment>%1 is a folder</comment>
-        <translation>Získává se seznam souborů v
+        <translation type="vanished">Získává se seznam souborů v
 %1</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="227"/>
+        <location filename="../src/musicanalyzer.cpp" line="226"/>
+        <source>Getting list of files under:</source>
+        <comment>A list of folders is shown below</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="231"/>
         <source>Cancel</source>
         <translation>Zrušit</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="230"/>
+        <location filename="../src/musicanalyzer.cpp" line="234"/>
         <source>Listing files...</source>
         <translation>Sestavuje se seznam souborů...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="361"/>
+        <location filename="../src/musicanalyzer.cpp" line="274"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>Please reload music info</source>
         <translation>Nahrajte, prosím, informace o hudbě</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="256"/>
+        <location filename="../src/musicanalyzer.cpp" line="275"/>
         <source>Music analysis was cancelled</source>
         <translation>Rozbor hudby byl zrušen</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="269"/>
+        <location filename="../src/musicanalyzer.cpp" line="288"/>
+        <source>There are no valid music files in your selected music folders.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <source>Please, select other folders containing Ogg, FLAC, Opus or MP3 files, and try again.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="312"/>
+        <source>Analyzing %1 files under:</source>
+        <comment>%1 is a number, and a folder list follows below</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation>Ve vámi vybraném adresáři s hudbou nejsou žádné platné hudební soubory.</translation>
+        <translation type="vanished">Ve vámi vybraném adresáři s hudbou nejsou žádné platné hudební soubory.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation>Vyberte, prosím, jiný adresář obsahující soubory Ogg, FLAC nebo MP3 a zkuste to znovu.</translation>
+        <translation type="vanished">Vyberte, prosím, jiný adresář obsahující soubory Ogg, FLAC nebo MP3 a zkuste to znovu.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="276"/>
+        <location filename="../src/musicanalyzer.cpp" line="295"/>
         <source>There is no music!</source>
         <translation>Není tu žádná hudba!</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="385"/>
+        <location filename="../src/musicanalyzer.cpp" line="299"/>
+        <location filename="../src/musicanalyzer.cpp" line="411"/>
         <source>Please choose another music folder</source>
         <translation>Vyberte, prosím, jiný adresář s hudbou</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
-        <translation>Provádí se rozbor %1 souborů
+        <translation type="vanished">Provádí se rozbor %1 souborů
 v %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="297"/>
+        <location filename="../src/musicanalyzer.cpp" line="319"/>
         <source>Cancel analysis</source>
         <translation>Zrušit rozbor</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="300"/>
+        <location filename="../src/musicanalyzer.cpp" line="322"/>
         <source>Analyzing your music...</source>
         <translation>Provádí se rozbor vaší hudby...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="386"/>
+        <location filename="../src/musicanalyzer.cpp" line="412"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>Vámi vybraná složka neobsahuje dost platných hudebních souborů</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="396"/>
+        <location filename="../src/musicanalyzer.cpp" line="422"/>
         <source>&amp;Start game</source>
         <translation>&amp;Spustit hru</translation>
     </message>
@@ -439,122 +457,147 @@ v %2</translation>
         <translation>Volby pro hru</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="59"/>
+        <location filename="../src/optionsdialog.cpp" line="62"/>
         <source>Using music from:</source>
         <translation>Používá se hudba z:</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="64"/>
         <source>Select your &amp;music folder...</source>
-        <translation>Vyberte složku s &amp;hudbou...</translation>
+        <translation type="vanished">Vyberte složku s &amp;hudbou...</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="83"/>
+        <location filename="../src/optionsdialog.cpp" line="70"/>
+        <source>Add a music folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="76"/>
+        <source>Remove selected folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="103"/>
         <source>&amp;Easier</source>
         <translation>&amp;Lehčí</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="98"/>
+        <location filename="../src/optionsdialog.cpp" line="117"/>
         <source>&amp;Harder</source>
         <translation>&amp;Těžší</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="126"/>
+        <location filename="../src/optionsdialog.cpp" line="144"/>
         <source>How many &amp;questions?</source>
         <translation>Kolik &amp;otázek?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="131"/>
+        <location filename="../src/optionsdialog.cpp" line="149"/>
         <source>questions</source>
         <translation>otázek</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="135"/>
+        <location filename="../src/optionsdialog.cpp" line="153"/>
         <source>How many &amp;players?</source>
         <translation>Kolik &amp;hráčů?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="140"/>
+        <location filename="../src/optionsdialog.cpp" line="158"/>
         <source>players</source>
         <translation>hráčů</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="144"/>
+        <location filename="../src/optionsdialog.cpp" line="162"/>
         <source>Use own color theme</source>
         <translation>Použít vlastní barevný motiv</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="209"/>
+        <location filename="../src/optionsdialog.cpp" line="227"/>
         <source>Player names</source>
         <translation>Jména hráčů</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="225"/>
+        <location filename="../src/optionsdialog.cpp" line="243"/>
         <source>Save and &amp;reload music</source>
         <translation>Uložit a &amp;nahrát hudbu znovu</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="234"/>
+        <location filename="../src/optionsdialog.cpp" line="252"/>
         <source>&amp;Cancel</source>
         <translation>Z&amp;rušit</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="304"/>
+        <location filename="../src/optionsdialog.cpp" line="383"/>
         <source>Select where your music is located</source>
         <translation>Vyberte, kde je vaše hudba umístěna</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="351"/>
+        <location filename="../src/optionsdialog.cpp" line="406"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="407"/>
+        <source>Cannot enter selected folder:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="411"/>
+        <source>Please choose another one.</source>
+        <comment>As in: another folder</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="463"/>
         <source>Piece of cake</source>
         <translation>Brnkačka</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="352"/>
+        <location filename="../src/optionsdialog.cpp" line="464"/>
         <source>Let&apos;s rock</source>
         <translation>Rozjedem to</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="353"/>
+        <location filename="../src/optionsdialog.cpp" line="465"/>
         <source>Come get some</source>
         <translation>Pojďme něco sehnat</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="354"/>
+        <location filename="../src/optionsdialog.cpp" line="466"/>
         <source>Damn I&apos;m good</source>
         <translation>Sakra, jsem dobrý</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="355"/>
+        <location filename="../src/optionsdialog.cpp" line="467"/>
         <source>HARD!!</source>
         <translation>Těžké!</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="356"/>
+        <location filename="../src/optionsdialog.cpp" line="468"/>
         <source>Hardcore! Type the answer</source>
         <translation>Těžké! Napište odpověď</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="363"/>
+        <location filename="../src/optionsdialog.cpp" line="475"/>
         <source>In this level you&apos;ll have to type the answer.</source>
         <translation>Na této úrovni musíte napsat odpověď.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="366"/>
+        <location filename="../src/optionsdialog.cpp" line="478"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
         <translation>Není to příliš přísné, takže se nemusíte obávat velikosti písmen, čárek a tak podobně.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="373"/>
+        <location filename="../src/optionsdialog.cpp" line="485"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
         <translation>Na této úrovni musíte klepnout na správné tlačítko, nebo na vaší klávesnici stisknout klávesu 1, 2, 3 nebo 4.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="460"/>
+        <location filename="../src/optionsdialog.cpp" line="573"/>
         <source>&amp;Save options</source>
         <translation>&amp;Uložit volby</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="490"/>
+        <location filename="../src/optionsdialog.cpp" line="606"/>
         <source>Start!</source>
         <translation>Začít!</translation>
     </message>
