@@ -4,7 +4,7 @@
 <context>
     <name>AnswerBox</name>
     <message>
-        <location filename="../src/answerbox.cpp" line="29"/>
+        <location filename="../src/answerbox.cpp" line="30"/>
         <source>Type the answer here</source>
         <translation>Teclea la respuesta aquí</translation>
     </message>
@@ -12,77 +12,77 @@
 <context>
     <name>AuralWindow</name>
     <message>
-        <location filename="../src/auralwindow.cpp" line="312"/>
+        <location filename="../src/auralwindow.cpp" line="269"/>
         <source>&amp;Start game</source>
         <translation>Comenzar &amp;juego</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="328"/>
+        <location filename="../src/auralwindow.cpp" line="285"/>
         <source>&amp;About...</source>
         <translation>&amp;Acerca de...</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="334"/>
+        <location filename="../src/auralwindow.cpp" line="291"/>
         <source>&amp;Quit</source>
         <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="430"/>
+        <location filename="../src/auralwindow.cpp" line="387"/>
         <source>Remaining time to answer this question</source>
         <translation>Tiempo restante para responder la pregunta</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="434"/>
+        <location filename="../src/auralwindow.cpp" line="391"/>
         <source>%v out of %m questions - %p%</source>
         <translation>%v de %m preguntas - %p%</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="437"/>
+        <location filename="../src/auralwindow.cpp" line="394"/>
         <source>How many questions you&apos;ve answered</source>
         <translation>Cuantas preguntas has respondido</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="439"/>
+        <location filename="../src/auralwindow.cpp" line="396"/>
         <source>Score</source>
         <translation>Puntuación</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="446"/>
+        <location filename="../src/auralwindow.cpp" line="403"/>
         <source>Your current score</source>
         <translation>Tu puntuación actual</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="454"/>
+        <location filename="../src/auralwindow.cpp" line="411"/>
         <source>&amp;End game</source>
         <translation>&amp;Finalizar juego</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="482"/>
+        <location filename="../src/auralwindow.cpp" line="439"/>
         <source>Statistics</source>
         <translation>Estadísticas</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="664"/>
+        <location filename="../src/auralwindow.cpp" line="622"/>
         <source>Sound system error</source>
         <translation>Error del sistema de sonido</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="665"/>
+        <location filename="../src/auralwindow.cpp" line="623"/>
         <source>There seems to be a problem with your sound system.</source>
         <translation>Parece que hay un problema con tu sistema de sonido.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="668"/>
+        <location filename="../src/auralwindow.cpp" line="626"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
         <translation>Quizá no tienes ningún motor de Phonon instalado.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="790"/>
+        <location filename="../src/auralwindow.cpp" line="749"/>
         <source>%1 songs available</source>
         <translation>%1 canciones disponibles</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1122"/>
+        <location filename="../src/auralwindow.cpp" line="1088"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
         <translation>Traducción al castellano por JanKusanagi.</translation>
@@ -109,12 +109,12 @@ Necesitas archivos correctamente etiquetados para que el juego funcione bien.
 El análisis puede tardar un poco, y el programa no responderá hasta que esté completo. Por favor, se paciente.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="944"/>
+        <location filename="../src/auralwindow.cpp" line="901"/>
         <source>Error playing sound</source>
         <translation>Error reproduciendo sonido</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="945"/>
+        <location filename="../src/auralwindow.cpp" line="902"/>
         <source>An error occurred while playing sound.
 The error message was: %1
 
@@ -125,119 +125,119 @@ El mensaje de error ha sido: %1
 Tal vez tu Phonon-backend no tenga soporte para el formato de archivo MP3.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1030"/>
+        <location filename="../src/auralwindow.cpp" line="997"/>
         <source>Time&apos;s up!!</source>
         <translation>¡Se acabó el tiempo!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1106"/>
+        <location filename="../src/auralwindow.cpp" line="1074"/>
         <source>About Auralquiz</source>
         <translation>Acerca de Auralquiz</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1117"/>
+        <location filename="../src/auralwindow.cpp" line="1084"/>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carga toda tu música de una carpeta especificada, y pregunta sobre ella, reproduciendo una pequeña pieza de cada archivo de música como pista.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="777"/>
+        <location filename="../src/auralwindow.cpp" line="736"/>
         <source>Starting!</source>
         <translation>¡Comenzamos!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="264"/>
+        <location filename="../src/auralwindow.cpp" line="220"/>
         <source>Good</source>
         <translation>Bien</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="273"/>
+        <location filename="../src/auralwindow.cpp" line="229"/>
         <source>Bad</source>
         <translation>Mal</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="282"/>
+        <location filename="../src/auralwindow.cpp" line="238"/>
         <source>Timed out</source>
         <translation>Tiempo agotado</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="778"/>
+        <location filename="../src/auralwindow.cpp" line="737"/>
         <source>Let&apos;s go!</source>
         <translation>¡Vamos!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="779"/>
+        <location filename="../src/auralwindow.cpp" line="738"/>
         <source>GO!!</source>
         <translation>¡Venga!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="780"/>
+        <location filename="../src/auralwindow.cpp" line="739"/>
         <source>Good luck!</source>
         <translation>¡Buena suerte!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1031"/>
+        <location filename="../src/auralwindow.cpp" line="998"/>
         <source>The answer was:</source>
         <translation>La respuesta era:</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1129"/>
+        <location filename="../src/auralwindow.cpp" line="1095"/>
         <source>Thanks to all the testers, translators and packagers, who help make Auralquiz better!</source>
         <translation>¡Gracias a todos los &apos;testers&apos;, traductores y empaquetadores, que ayudan a hacer Auralquiz mejor!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1133"/>
+        <location filename="../src/auralwindow.cpp" line="1098"/>
         <source>Auralquiz is licensed under the GNU GPL license.</source>
         <translation>Auralquiz está licenciado bajo la licencia GNU GPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1135"/>
+        <location filename="../src/auralwindow.cpp" line="1100"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
         <translation>La imagen de la pantalla principal, y algunos iconos, están basados en Oxygen Icons, bajo licencia LGPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1208"/>
+        <location filename="../src/auralwindow.cpp" line="1185"/>
         <source>Player %1 of %2</source>
         <translation>Jugador %1 de %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1373"/>
+        <location filename="../src/auralwindow.cpp" line="1351"/>
         <source>Go, %1!</source>
         <comment>%1=player&apos;s name</comment>
         <translation>¡Adelante, %1!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1470"/>
+        <location filename="../src/auralwindow.cpp" line="1448"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
         <translation>%1 de %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1475"/>
+        <location filename="../src/auralwindow.cpp" line="1453"/>
         <source>+%1 points!</source>
         <translation>¡+%1 puntos!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1501"/>
+        <location filename="../src/auralwindow.cpp" line="1479"/>
         <source>Correct answer was:</source>
         <translation>La respuesta correcta era:</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1572"/>
+        <location filename="../src/auralwindow.cpp" line="1550"/>
         <source>End game?</source>
         <translation>¿Finalizar el juego?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1573"/>
+        <location filename="../src/auralwindow.cpp" line="1551"/>
         <source>Are you sure you want to end this game?</source>
         <translation>¿Seguro que quieres terminar la partida?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;Yes, end it</source>
         <translation>&amp;Sí, terminarla</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;No</source>
         <translation>&amp;No</translation>
     </message>
@@ -247,94 +247,94 @@ Tal vez tu Phonon-backend no tenga soporte para el formato de archivo MP3.</tran
         <translation>Primer uso</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1319"/>
+        <location filename="../src/auralwindow.cpp" line="1297"/>
         <source>Not enough music files</source>
         <translation>No hay suficientes archivos de música</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1320"/>
+        <location filename="../src/auralwindow.cpp" line="1298"/>
         <source>You don&apos;t have enough music files, or from enough different artists.
 You need music from at least 5 different artists to be able to generate questions.</source>
         <translation>No tienes suficientes archivos de música, o de suficientes artistas diferentes.
 Necesitas música de al menos 5 artistas diferentes para poder generar preguntas.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1379"/>
+        <location filename="../src/auralwindow.cpp" line="1357"/>
         <source>Next!</source>
         <translation>¡Siguiente!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1454"/>
+        <location filename="../src/auralwindow.cpp" line="1432"/>
         <source>Correct!!</source>
         <translation>¡¡Correcto!!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1455"/>
+        <location filename="../src/auralwindow.cpp" line="1433"/>
         <source>Yeah!</source>
         <translation>¡Sí!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1456"/>
+        <location filename="../src/auralwindow.cpp" line="1434"/>
         <source>That&apos;s right!</source>
         <translation>¡Así es!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1457"/>
+        <location filename="../src/auralwindow.cpp" line="1435"/>
         <source>Good!</source>
         <translation>¡Bien!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1458"/>
+        <location filename="../src/auralwindow.cpp" line="1436"/>
         <source>Great!</source>
         <translation>¡Genial!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1486"/>
+        <location filename="../src/auralwindow.cpp" line="1464"/>
         <source>Wrong!</source>
         <translation>¡Equivocado!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1487"/>
+        <location filename="../src/auralwindow.cpp" line="1465"/>
         <source>No!</source>
         <translation>¡No!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1489"/>
+        <location filename="../src/auralwindow.cpp" line="1467"/>
         <source>Ooops!</source>
         <translation>¡Ups!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1490"/>
+        <location filename="../src/auralwindow.cpp" line="1468"/>
         <source>FAIL!</source>
         <translation>FAIL!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1488"/>
+        <location filename="../src/auralwindow.cpp" line="1466"/>
         <source>That&apos;s not it.</source>
         <translation>No, esa no.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1408"/>
+        <location filename="../src/auralwindow.cpp" line="1386"/>
         <source>All done!</source>
         <translation>¡Todo hecho!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="321"/>
+        <location filename="../src/auralwindow.cpp" line="278"/>
         <source>&amp;Options</source>
         <translation>&amp;Opciones</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="427"/>
+        <location filename="../src/auralwindow.cpp" line="384"/>
         <source>Time</source>
         <translation>Tiempo</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1198"/>
+        <location filename="../src/auralwindow.cpp" line="1172"/>
         <source>Who plays this song?</source>
         <translation>¿Quien toca esta canción?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1202"/>
+        <location filename="../src/auralwindow.cpp" line="1176"/>
         <source>What&apos;s the title of this song?</source>
         <translation>¿Cual es el título de esta canción?</translation>
     </message>
@@ -342,89 +342,107 @@ Necesitas música de al menos 5 artistas diferentes para poder generar preguntas
 <context>
     <name>MusicAnalyzer</name>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="125"/>
+        <location filename="../src/musicanalyzer.cpp" line="121"/>
         <source>Configure your music folder</source>
         <translation>Configura tu carpeta de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="214"/>
+        <location filename="../src/musicanalyzer.cpp" line="216"/>
         <source>Analyzing music. Please wait</source>
         <translation>Analizando música. Espera, por favor</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="223"/>
         <source>Getting list of files under
 %1</source>
         <comment>%1 is a folder</comment>
-        <translation>Listando archivos en
+        <translation type="vanished">Listando archivos en
 %1</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="227"/>
+        <location filename="../src/musicanalyzer.cpp" line="226"/>
+        <source>Getting list of files under:</source>
+        <comment>A list of folders is shown below</comment>
+        <translation>Listando archivos en:</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="231"/>
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="230"/>
+        <location filename="../src/musicanalyzer.cpp" line="234"/>
         <source>Listing files...</source>
         <translation>Listando archivos...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="361"/>
+        <location filename="../src/musicanalyzer.cpp" line="274"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>Please reload music info</source>
         <translation>Por favor, recarga la info de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="256"/>
+        <location filename="../src/musicanalyzer.cpp" line="275"/>
         <source>Music analysis was cancelled</source>
         <translation>Se ha cancelado el análisis de la música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="269"/>
+        <location filename="../src/musicanalyzer.cpp" line="288"/>
+        <source>There are no valid music files in your selected music folders.</source>
+        <translation>No hay archivos de música válidos en tus carpetas de música seleccionadas.</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <source>Please, select other folders containing Ogg, FLAC, Opus or MP3 files, and try again.</source>
+        <translation>Por favor, selecciona otras carpetas que contengan archivos Ogg, FLAC, Opus o MP3, e inténtalo de nuevo.</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="312"/>
+        <source>Analyzing %1 files under:</source>
+        <comment>%1 is a number, and a folder list follows below</comment>
+        <translation>Analizando %1 archivos en:</translation>
+    </message>
+    <message>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation>No hay archivos de música válidos en tu directorio de música seleccionado.</translation>
+        <translation type="vanished">No hay archivos de música válidos en tu directorio de música seleccionado.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation>Por favor, selecciona otro directorio que contenga archivos Ogg, FLAC o MP3, e inténtalo de nuevo.</translation>
+        <translation type="vanished">Por favor, selecciona otro directorio que contenga archivos Ogg, FLAC o MP3, e inténtalo de nuevo.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="276"/>
+        <location filename="../src/musicanalyzer.cpp" line="295"/>
         <source>There is no music!</source>
         <translation>¡No hay música!</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="385"/>
+        <location filename="../src/musicanalyzer.cpp" line="299"/>
+        <location filename="../src/musicanalyzer.cpp" line="411"/>
         <source>Please choose another music folder</source>
         <translation>Por favor, selecciona otra carpeta de música</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
-        <translation>Analizando %1 archivos en %2</translation>
+        <translation type="vanished">Analizando %1 archivos en %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="297"/>
+        <location filename="../src/musicanalyzer.cpp" line="319"/>
         <source>Cancel analysis</source>
         <translation>Cancelar análisis</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="300"/>
+        <location filename="../src/musicanalyzer.cpp" line="322"/>
         <source>Analyzing your music...</source>
         <translation>Analizando tu música...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="386"/>
+        <location filename="../src/musicanalyzer.cpp" line="412"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>La carpeta que has seleccionado no tiene suficientes archivos de música válidos</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="396"/>
+        <location filename="../src/musicanalyzer.cpp" line="422"/>
         <source>&amp;Start game</source>
         <translation>Comenzar &amp;juego</translation>
     </message>
@@ -437,122 +455,147 @@ under %2</source>
         <translation>Opciones del juego</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="59"/>
+        <location filename="../src/optionsdialog.cpp" line="62"/>
         <source>Using music from:</source>
         <translation>Usando música de:</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="64"/>
         <source>Select your &amp;music folder...</source>
-        <translation>Selecciona tu carpeta de &amp;música...</translation>
+        <translation type="vanished">Selecciona tu carpeta de &amp;música...</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="83"/>
+        <location filename="../src/optionsdialog.cpp" line="103"/>
         <source>&amp;Easier</source>
         <translation>Más &amp;fácil</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="98"/>
+        <location filename="../src/optionsdialog.cpp" line="117"/>
         <source>&amp;Harder</source>
         <translation>Más &amp;difícil</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="126"/>
+        <location filename="../src/optionsdialog.cpp" line="144"/>
         <source>How many &amp;questions?</source>
         <translation>¿Cuantas &amp;preguntas?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="131"/>
+        <location filename="../src/optionsdialog.cpp" line="149"/>
         <source>questions</source>
         <translation>preguntas</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="135"/>
+        <location filename="../src/optionsdialog.cpp" line="153"/>
         <source>How many &amp;players?</source>
         <translation>¿Cuantos &amp;jugadores?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="140"/>
+        <location filename="../src/optionsdialog.cpp" line="158"/>
         <source>players</source>
         <translation>jugadores</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="144"/>
+        <location filename="../src/optionsdialog.cpp" line="162"/>
         <source>Use own color theme</source>
         <translation>Usar tema de colores propio</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="209"/>
+        <location filename="../src/optionsdialog.cpp" line="227"/>
         <source>Player names</source>
         <translation>Nombres de los jugadores</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="225"/>
+        <location filename="../src/optionsdialog.cpp" line="243"/>
         <source>Save and &amp;reload music</source>
         <translation>Guardar y &amp;recargar la música</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="363"/>
+        <location filename="../src/optionsdialog.cpp" line="406"/>
+        <source>Error</source>
+        <translation>Error</translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="407"/>
+        <source>Cannot enter selected folder:</source>
+        <translation>No se puede entrar en la carpeta seleccionada:</translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="411"/>
+        <source>Please choose another one.</source>
+        <comment>As in: another folder</comment>
+        <translation>Por favor, elige otra.</translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="475"/>
         <source>In this level you&apos;ll have to type the answer.</source>
         <translation>En este nivel tendrás que teclear la respuesta.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="366"/>
+        <location filename="../src/optionsdialog.cpp" line="478"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
         <translation>No es muy estricto, así que no te has de preocupar de las mayúsculas, comas, etc.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="373"/>
+        <location filename="../src/optionsdialog.cpp" line="485"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
         <translation>En este nivel tendrás que hacer click en el botón correcto, o apretar las teclas 1, 2, 3 y 4 del teclado.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="460"/>
+        <location filename="../src/optionsdialog.cpp" line="573"/>
         <source>&amp;Save options</source>
         <translation>&amp;Guardar opciones</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="234"/>
+        <location filename="../src/optionsdialog.cpp" line="252"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Cancelar</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="304"/>
+        <location filename="../src/optionsdialog.cpp" line="70"/>
+        <source>Add a music folder...</source>
+        <translation>Añadir una carpeta de música...</translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="76"/>
+        <source>Remove selected folder</source>
+        <translation>Quitar carpeta seleccionada</translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="383"/>
         <source>Select where your music is located</source>
         <translation>Selecciona donde se encuentra tu música</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="351"/>
+        <location filename="../src/optionsdialog.cpp" line="463"/>
         <source>Piece of cake</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="352"/>
+        <location filename="../src/optionsdialog.cpp" line="464"/>
         <source>Let&apos;s rock</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="353"/>
+        <location filename="../src/optionsdialog.cpp" line="465"/>
         <source>Come get some</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="354"/>
+        <location filename="../src/optionsdialog.cpp" line="466"/>
         <source>Damn I&apos;m good</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="355"/>
+        <location filename="../src/optionsdialog.cpp" line="467"/>
         <source>HARD!!</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="356"/>
+        <location filename="../src/optionsdialog.cpp" line="468"/>
         <source>Hardcore! Type the answer</source>
         <translation>¡Muy difícil! Teclea la respuesta</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="490"/>
+        <location filename="../src/optionsdialog.cpp" line="606"/>
         <source>Start!</source>
         <translation>¡Comenzar!</translation>
     </message>
