@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="fr">
+<TS version="2.1" language="fr_FR">
 <context>
     <name>AnswerBox</name>
     <message>
-        <location filename="../src/answerbox.cpp" line="29"/>
+        <location filename="../src/answerbox.cpp" line="30"/>
         <source>Type the answer here</source>
         <translation>Tapez la réponse ici</translation>
     </message>
@@ -38,98 +38,98 @@ Vous avez besoin de fichiers correctement taggés pour que le jeu fonctionne bie
 Le scan peut durer longtemps, et le programme peut ne plus répondre tant que ce n&apos;est pas fini. Soyez patient.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="312"/>
+        <location filename="../src/auralwindow.cpp" line="269"/>
         <source>&amp;Start game</source>
         <translation>&amp;Démarrer le jeu</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="321"/>
+        <location filename="../src/auralwindow.cpp" line="278"/>
         <source>&amp;Options</source>
         <translation>&amp;Options</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="328"/>
+        <location filename="../src/auralwindow.cpp" line="285"/>
         <source>&amp;About...</source>
         <translation>À &amp;propos...</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="334"/>
+        <location filename="../src/auralwindow.cpp" line="291"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="427"/>
+        <location filename="../src/auralwindow.cpp" line="384"/>
         <source>Time</source>
         <translation>Temps</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="430"/>
+        <location filename="../src/auralwindow.cpp" line="387"/>
         <source>Remaining time to answer this question</source>
         <translation>Temps restant pour répondre à cette question</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="434"/>
+        <location filename="../src/auralwindow.cpp" line="391"/>
         <source>%v out of %m questions - %p%</source>
         <translation>%v sur %m questions - %p%</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="437"/>
+        <location filename="../src/auralwindow.cpp" line="394"/>
         <source>How many questions you&apos;ve answered</source>
         <translation>À combien de questions vous avez répondu</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="439"/>
+        <location filename="../src/auralwindow.cpp" line="396"/>
         <source>Score</source>
         <translation>Score</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="446"/>
+        <location filename="../src/auralwindow.cpp" line="403"/>
         <source>Your current score</source>
         <translation>Votre score actuel</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="454"/>
+        <location filename="../src/auralwindow.cpp" line="411"/>
         <source>&amp;End game</source>
         <translation>&amp;Terminer le jeu</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="482"/>
+        <location filename="../src/auralwindow.cpp" line="439"/>
         <source>Statistics</source>
         <translation>Statistiques</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="664"/>
+        <location filename="../src/auralwindow.cpp" line="622"/>
         <source>Sound system error</source>
         <translation>Erreur du système de son</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="665"/>
+        <location filename="../src/auralwindow.cpp" line="623"/>
         <source>There seems to be a problem with your sound system.</source>
         <translation>Il semble qu&apos;il y a un problème avec votre système de son.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="668"/>
+        <location filename="../src/auralwindow.cpp" line="626"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
         <translation>Peut-être que vous n&apos;avez aucun backend Phonon d&apos;installé.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="790"/>
+        <location filename="../src/auralwindow.cpp" line="749"/>
         <source>%1 songs available</source>
         <translation>%1 chansons disponibles</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1122"/>
+        <location filename="../src/auralwindow.cpp" line="1088"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
         <translation>Traduction française par ntome, Adrien DAUGABEL et David GEIGER.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="944"/>
+        <location filename="../src/auralwindow.cpp" line="901"/>
         <source>Error playing sound</source>
         <translation>Erreur en jouant un son</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="945"/>
+        <location filename="../src/auralwindow.cpp" line="902"/>
         <source>An error occurred while playing sound.
 The error message was: %1
 
@@ -140,201 +140,201 @@ Le message d&apos;erreur était : %1
 Peut-être que votre backend Phonon ne supporte pas le format de fichier MP3.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1030"/>
+        <location filename="../src/auralwindow.cpp" line="997"/>
         <source>Time&apos;s up!!</source>
         <translation>Temps écoulé !!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1106"/>
+        <location filename="../src/auralwindow.cpp" line="1074"/>
         <source>About Auralquiz</source>
         <translation>À propos d&apos;Auralquiz</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1117"/>
+        <location filename="../src/auralwindow.cpp" line="1084"/>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz charge toute votre musique depuis un certain dossier et pose des questions dessus, en jouant un petit morceau de chaque musique comme indice.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="777"/>
+        <location filename="../src/auralwindow.cpp" line="736"/>
         <source>Starting!</source>
         <translation>À vos marques !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="264"/>
+        <location filename="../src/auralwindow.cpp" line="220"/>
         <source>Good</source>
         <translation>Bon</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="273"/>
+        <location filename="../src/auralwindow.cpp" line="229"/>
         <source>Bad</source>
         <translation>Mauvais</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="282"/>
+        <location filename="../src/auralwindow.cpp" line="238"/>
         <source>Timed out</source>
         <translation>Temps écoulé</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="778"/>
+        <location filename="../src/auralwindow.cpp" line="737"/>
         <source>Let&apos;s go!</source>
         <translation>Prêts ?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="779"/>
+        <location filename="../src/auralwindow.cpp" line="738"/>
         <source>GO!!</source>
         <translation>PARTEZ !!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="780"/>
+        <location filename="../src/auralwindow.cpp" line="739"/>
         <source>Good luck!</source>
         <translation>Bonne chance !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1031"/>
+        <location filename="../src/auralwindow.cpp" line="998"/>
         <source>The answer was:</source>
         <translation>La réponse était :</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1129"/>
+        <location filename="../src/auralwindow.cpp" line="1095"/>
         <source>Thanks to all the testers, translators and packagers, who help make Auralquiz better!</source>
         <translation>Merci à tous les testeurs, traducteurs et packageurs, qui contribuent à l&apos;amélioration d&apos;Auralquiz !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1133"/>
+        <location filename="../src/auralwindow.cpp" line="1098"/>
         <source>Auralquiz is licensed under the GNU GPL license.</source>
         <translation>Auralquiz est sous licence GNU GPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1135"/>
+        <location filename="../src/auralwindow.cpp" line="1100"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
         <translation>L&apos;image de l&apos;écran principal et les icônes sont basés sur les icones Oxygen, sous licence LGPL.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1198"/>
+        <location filename="../src/auralwindow.cpp" line="1172"/>
         <source>Who plays this song?</source>
         <translation>Qui joue ce morceau ?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1202"/>
+        <location filename="../src/auralwindow.cpp" line="1176"/>
         <source>What&apos;s the title of this song?</source>
         <translation>Quel est le titre de ce morceau ?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1208"/>
+        <location filename="../src/auralwindow.cpp" line="1185"/>
         <source>Player %1 of %2</source>
         <translation>Joueur %1 sur %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1319"/>
+        <location filename="../src/auralwindow.cpp" line="1297"/>
         <source>Not enough music files</source>
         <translation>Pas assez de fichiers musicaux</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1320"/>
+        <location filename="../src/auralwindow.cpp" line="1298"/>
         <source>You don&apos;t have enough music files, or from enough different artists.
 You need music from at least 5 different artists to be able to generate questions.</source>
         <translation>Vous n&apos;avez pas assez de fichiers musicaux, ou pas assez d&apos;artistes différents.
 Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir générer des questions.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1373"/>
+        <location filename="../src/auralwindow.cpp" line="1351"/>
         <source>Go, %1!</source>
         <comment>%1=player&apos;s name</comment>
         <translation>Allez, %1 !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1470"/>
+        <location filename="../src/auralwindow.cpp" line="1448"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
         <translation>%1 par %2</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1501"/>
+        <location filename="../src/auralwindow.cpp" line="1479"/>
         <source>Correct answer was:</source>
         <translation>La bonne réponse était :</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1572"/>
+        <location filename="../src/auralwindow.cpp" line="1550"/>
         <source>End game?</source>
         <translation>Terminer la partie ?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1573"/>
+        <location filename="../src/auralwindow.cpp" line="1551"/>
         <source>Are you sure you want to end this game?</source>
         <translation>Etes-vous sûr de vouloir terminer cette partie ?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;Yes, end it</source>
         <translation>&amp;Oui, terminer</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;No</source>
         <translation>&amp;Non</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1379"/>
+        <location filename="../src/auralwindow.cpp" line="1357"/>
         <source>Next!</source>
         <translation>Suivant !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1408"/>
+        <location filename="../src/auralwindow.cpp" line="1386"/>
         <source>All done!</source>
         <translation>Terminé !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1454"/>
+        <location filename="../src/auralwindow.cpp" line="1432"/>
         <source>Correct!!</source>
         <translation>Correct !!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1455"/>
+        <location filename="../src/auralwindow.cpp" line="1433"/>
         <source>Yeah!</source>
         <translation>Yeah !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1456"/>
+        <location filename="../src/auralwindow.cpp" line="1434"/>
         <source>That&apos;s right!</source>
         <translation>C&apos;est juste !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1457"/>
+        <location filename="../src/auralwindow.cpp" line="1435"/>
         <source>Good!</source>
         <translation>Bien !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1458"/>
+        <location filename="../src/auralwindow.cpp" line="1436"/>
         <source>Great!</source>
         <translation>Génial !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1475"/>
+        <location filename="../src/auralwindow.cpp" line="1453"/>
         <source>+%1 points!</source>
         <translation>+%1 points !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1486"/>
+        <location filename="../src/auralwindow.cpp" line="1464"/>
         <source>Wrong!</source>
         <translation>Faux !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1487"/>
+        <location filename="../src/auralwindow.cpp" line="1465"/>
         <source>No!</source>
         <translation>Non !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1488"/>
+        <location filename="../src/auralwindow.cpp" line="1466"/>
         <source>That&apos;s not it.</source>
         <translation>Ce n&apos;est pas ça.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1489"/>
+        <location filename="../src/auralwindow.cpp" line="1467"/>
         <source>Ooops!</source>
         <translation>Ouuups !</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1490"/>
+        <location filename="../src/auralwindow.cpp" line="1468"/>
         <source>FAIL!</source>
         <translation>RATÉ !</translation>
     </message>
@@ -342,89 +342,109 @@ Vous avez besoin de musique d&apos;au moins 5 artistes différents pour pouvoir
 <context>
     <name>MusicAnalyzer</name>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="125"/>
+        <location filename="../src/musicanalyzer.cpp" line="121"/>
         <source>Configure your music folder</source>
         <translation>Configurer votre dossier de musique</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="214"/>
+        <location filename="../src/musicanalyzer.cpp" line="216"/>
         <source>Analyzing music. Please wait</source>
         <translation>Analyse de la musique. Veuillez patienter</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="223"/>
         <source>Getting list of files under
 %1</source>
         <comment>%1 is a folder</comment>
-        <translation>Obtention de la liste des fichiers dans %1</translation>
+        <translation type="vanished">Obtention de la liste des fichiers dans %1</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="227"/>
+        <location filename="../src/musicanalyzer.cpp" line="226"/>
+        <source>Getting list of files under:</source>
+        <comment>A list of folders is shown below</comment>
+        <translation type="unfinished">Obtention de la liste des fichiers dans:</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="231"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="230"/>
+        <location filename="../src/musicanalyzer.cpp" line="234"/>
         <source>Listing files...</source>
         <translation>Liste les fichiers...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="361"/>
+        <location filename="../src/musicanalyzer.cpp" line="274"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>Please reload music info</source>
         <translation>Merci de recharger les informations de la musique</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="256"/>
+        <location filename="../src/musicanalyzer.cpp" line="275"/>
         <source>Music analysis was cancelled</source>
         <translation>L&apos;analyse de la musique a été annulée</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="269"/>
+        <location filename="../src/musicanalyzer.cpp" line="288"/>
+        <source>There are no valid music files in your selected music folders.</source>
+        <translatorcomment>**JanKusanagi: needs fixing for plural</translatorcomment>
+        <translation type="unfinished">Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <source>Please, select other folders containing Ogg, FLAC, Opus or MP3 files, and try again.</source>
+        <translatorcomment>**JanKusanagi: needs updating for plural</translatorcomment>
+        <translation type="unfinished">Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC, Opus ou MP3 puis réessayez.</translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="312"/>
+        <source>Analyzing %1 files under:</source>
+        <comment>%1 is a number, and a folder list follows below</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation>Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.</translation>
+        <translation type="vanished">Il n&apos;y a pas de fichier de musique valide dans le dossier de musique sélectionné.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation>Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC ou MP3 puis réessayez.</translation>
+        <translation type="vanished">Veuillez sélectionner un autre dossier contenant des fichiers Ogg, FLAC ou MP3 puis réessayez.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="276"/>
+        <location filename="../src/musicanalyzer.cpp" line="295"/>
         <source>There is no music!</source>
         <translation>Il n&apos;y a pas de musique !</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="385"/>
+        <location filename="../src/musicanalyzer.cpp" line="299"/>
+        <location filename="../src/musicanalyzer.cpp" line="411"/>
         <source>Please choose another music folder</source>
         <translation>Veuillez sélectionner un autre dossier de musique</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
-        <translation>Analyse %1 fichiers
+        <translation type="vanished">Analyse %1 fichiers
 dans %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="297"/>
+        <location filename="../src/musicanalyzer.cpp" line="319"/>
         <source>Cancel analysis</source>
         <translation>Annuler l&apos;analyse</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="300"/>
+        <location filename="../src/musicanalyzer.cpp" line="322"/>
         <source>Analyzing your music...</source>
         <translation>Analyse votre musique...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="386"/>
+        <location filename="../src/musicanalyzer.cpp" line="412"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation>Le dossier que vous avez sélectionné n&apos;a pas assez de fichiers de musique valide</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="396"/>
+        <location filename="../src/musicanalyzer.cpp" line="422"/>
         <source>&amp;Start game</source>
         <translation>&amp;Démarrer le jeu</translation>
     </message>
@@ -437,126 +457,151 @@ dans %2</translation>
         <translation>Options du jeu</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="59"/>
+        <location filename="../src/optionsdialog.cpp" line="62"/>
         <source>Using music from:</source>
         <translation>Utilise la musique de :</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="64"/>
         <source>Select your &amp;music folder...</source>
-        <translation>Sélectionnez votre dossier de &amp;musique...</translation>
+        <translation type="vanished">Sélectionnez votre dossier de &amp;musique...</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="83"/>
+        <location filename="../src/optionsdialog.cpp" line="70"/>
+        <source>Add a music folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="76"/>
+        <source>Remove selected folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="103"/>
         <source>&amp;Easier</source>
         <translation>&amp;Plus facile</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="98"/>
+        <location filename="../src/optionsdialog.cpp" line="117"/>
         <source>&amp;Harder</source>
         <translation>&amp;Plus difficile</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="126"/>
+        <location filename="../src/optionsdialog.cpp" line="144"/>
         <source>How many &amp;questions?</source>
         <translation>Combien de &amp;questions ?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="131"/>
+        <location filename="../src/optionsdialog.cpp" line="149"/>
         <source>questions</source>
         <translation>questions</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="135"/>
+        <location filename="../src/optionsdialog.cpp" line="153"/>
         <source>How many &amp;players?</source>
         <translation>Combien de &amp;joueurs ?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="140"/>
+        <location filename="../src/optionsdialog.cpp" line="158"/>
         <source>players</source>
         <translation>joueurs</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="144"/>
+        <location filename="../src/optionsdialog.cpp" line="162"/>
         <source>Use own color theme</source>
         <translation>Utiliser le thème de couleur spécial</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="209"/>
+        <location filename="../src/optionsdialog.cpp" line="227"/>
         <source>Player names</source>
         <translation>Noms des joueurs</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="225"/>
+        <location filename="../src/optionsdialog.cpp" line="243"/>
         <source>Save and &amp;reload music</source>
         <translation>Enregistrer et &amp;recharger la musique</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="234"/>
+        <location filename="../src/optionsdialog.cpp" line="252"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="304"/>
+        <location filename="../src/optionsdialog.cpp" line="383"/>
         <source>Select where your music is located</source>
         <translation>Sélectionnez le dossier où se trouve votre musique</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="351"/>
+        <location filename="../src/optionsdialog.cpp" line="406"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="407"/>
+        <source>Cannot enter selected folder:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="411"/>
+        <source>Please choose another one.</source>
+        <comment>As in: another folder</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="463"/>
         <source>Piece of cake</source>
         <translatorcomment>not translated for DN3D reference</translatorcomment>
         <translation>Piece of cake</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="352"/>
+        <location filename="../src/optionsdialog.cpp" line="464"/>
         <source>Let&apos;s rock</source>
         <translatorcomment>not translated for DN3D reference</translatorcomment>
         <translation>Let&apos;s rock</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="353"/>
+        <location filename="../src/optionsdialog.cpp" line="465"/>
         <source>Come get some</source>
         <translatorcomment>not translated for DN3D reference</translatorcomment>
         <translation>Come get some</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="354"/>
+        <location filename="../src/optionsdialog.cpp" line="466"/>
         <source>Damn I&apos;m good</source>
         <translatorcomment>not translated for DN3D reference</translatorcomment>
         <translation>Damn I&apos;m good</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="355"/>
+        <location filename="../src/optionsdialog.cpp" line="467"/>
         <source>HARD!!</source>
         <translation>Difficile !!</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="356"/>
+        <location filename="../src/optionsdialog.cpp" line="468"/>
         <source>Hardcore! Type the answer</source>
         <translation>Super difficile ! Taper la réponse</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="363"/>
+        <location filename="../src/optionsdialog.cpp" line="475"/>
         <source>In this level you&apos;ll have to type the answer.</source>
         <translation>Dans ce niveau, vous devrez taper la réponse.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="366"/>
+        <location filename="../src/optionsdialog.cpp" line="478"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
         <translation>Ce n&apos;est pas trop strict, vous n&apos;avez pas besoin de mettre les majuscules, virgules etc.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="373"/>
+        <location filename="../src/optionsdialog.cpp" line="485"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
         <translation>Dans ce niveau, vous devrez cliquer sur le bon bouton, ou appuyer sur les touches 1, 2, 3 ou 4 de votre clavier.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="460"/>
+        <location filename="../src/optionsdialog.cpp" line="573"/>
         <source>&amp;Save options</source>
         <translation>&amp;Enregistrer les options</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="490"/>
+        <location filename="../src/optionsdialog.cpp" line="606"/>
         <source>Start!</source>
         <translation>Démarrer !</translation>
     </message>
