@@ -4,7 +4,7 @@
 <context>
     <name>AnswerBox</name>
     <message>
-        <location filename="../src/answerbox.cpp" line="29"/>
+        <location filename="../src/answerbox.cpp" line="30"/>
         <source>Type the answer here</source>
         <translation>Scrivi la risposta qui</translation>
     </message>
@@ -12,77 +12,77 @@
 <context>
     <name>AuralWindow</name>
     <message>
-        <location filename="../src/auralwindow.cpp" line="312"/>
+        <location filename="../src/auralwindow.cpp" line="269"/>
         <source>&amp;Start game</source>
         <translation>Inizio &amp;gioco</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="328"/>
+        <location filename="../src/auralwindow.cpp" line="285"/>
         <source>&amp;About...</source>
         <translation>&amp;About...</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="334"/>
+        <location filename="../src/auralwindow.cpp" line="291"/>
         <source>&amp;Quit</source>
         <translation>&amp;Esci</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="430"/>
+        <location filename="../src/auralwindow.cpp" line="387"/>
         <source>Remaining time to answer this question</source>
         <translation>Tempo restante per rispondere alla domanda</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="434"/>
+        <location filename="../src/auralwindow.cpp" line="391"/>
         <source>%v out of %m questions - %p%</source>
         <translation>%v di %m domande - %p%</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="437"/>
+        <location filename="../src/auralwindow.cpp" line="394"/>
         <source>How many questions you&apos;ve answered</source>
         <translation>Quante domande hai risposto</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="439"/>
+        <location filename="../src/auralwindow.cpp" line="396"/>
         <source>Score</source>
         <translation>Punteggio</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="446"/>
+        <location filename="../src/auralwindow.cpp" line="403"/>
         <source>Your current score</source>
         <translation>Punteggio attuale</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="454"/>
+        <location filename="../src/auralwindow.cpp" line="411"/>
         <source>&amp;End game</source>
         <translation>&amp;Fine gioco</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="482"/>
+        <location filename="../src/auralwindow.cpp" line="439"/>
         <source>Statistics</source>
         <translation>Statistiche</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="664"/>
+        <location filename="../src/auralwindow.cpp" line="622"/>
         <source>Sound system error</source>
         <translation>Errore del sistema sonoro</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="665"/>
+        <location filename="../src/auralwindow.cpp" line="623"/>
         <source>There seems to be a problem with your sound system.</source>
         <translation>Sembra ci sia un problema con il tuo sistema sonoro.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="668"/>
+        <location filename="../src/auralwindow.cpp" line="626"/>
         <source>Maybe you don&apos;t have any Phonon backends installed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="790"/>
+        <location filename="../src/auralwindow.cpp" line="749"/>
         <source>%1 songs available</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1122"/>
+        <location filename="../src/auralwindow.cpp" line="1088"/>
         <source>English translation by JanKusanagi.</source>
         <comment>TRANSLATORS: Change this with your language and name. Feel free to add your contact information, such as e-mail. If there was another translator before you, add your name after theirs ;)</comment>
         <translation type="unfinished">Traduzione in italiano di Giovanni.</translation>
@@ -109,12 +109,12 @@ Bisogna che i file abbiano i tag corretti per far sì che il gioco funzioni corr
 L&apos;analisi può richiedere un po&apos; di tempo, il programma non sarà responsivo finchè non sarà terminata. Per favore abbi pazienza.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="944"/>
+        <location filename="../src/auralwindow.cpp" line="901"/>
         <source>Error playing sound</source>
         <translation>Errore riproduzione suoni</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="945"/>
+        <location filename="../src/auralwindow.cpp" line="902"/>
         <source>An error occurred while playing sound.
 The error message was: %1
 
@@ -125,119 +125,119 @@ Il messaggio di errore è: %1
 Forse il tuo Phonon-backend non supporta i file in formato MP3.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1030"/>
+        <location filename="../src/auralwindow.cpp" line="997"/>
         <source>Time&apos;s up!!</source>
         <translation>Tempo scaduto!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1106"/>
+        <location filename="../src/auralwindow.cpp" line="1074"/>
         <source>About Auralquiz</source>
         <translation>About Auralquiz</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1117"/>
+        <location filename="../src/auralwindow.cpp" line="1084"/>
         <source>Auralquiz loads all your music from a specified folder and asks questions about it, playing a short piece of each music file as clue.</source>
         <translation>Auralquiz carica tutta la tua musica da una cartella specificata e ti fa domande su di essa, riproducendo un breve pezzo di ogni file come indizio.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="777"/>
+        <location filename="../src/auralwindow.cpp" line="736"/>
         <source>Starting!</source>
         <translation>Inizio!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="264"/>
+        <location filename="../src/auralwindow.cpp" line="220"/>
         <source>Good</source>
         <translation type="unfinished">Giuste</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="273"/>
+        <location filename="../src/auralwindow.cpp" line="229"/>
         <source>Bad</source>
         <translation type="unfinished">Sbagliate</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="282"/>
+        <location filename="../src/auralwindow.cpp" line="238"/>
         <source>Timed out</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="778"/>
+        <location filename="../src/auralwindow.cpp" line="737"/>
         <source>Let&apos;s go!</source>
         <translation>Andiamo!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="779"/>
+        <location filename="../src/auralwindow.cpp" line="738"/>
         <source>GO!!</source>
         <translation>VAI!!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="780"/>
+        <location filename="../src/auralwindow.cpp" line="739"/>
         <source>Good luck!</source>
         <translation>Buona fortuna!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1031"/>
+        <location filename="../src/auralwindow.cpp" line="998"/>
         <source>The answer was:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1129"/>
+        <location filename="../src/auralwindow.cpp" line="1095"/>
         <source>Thanks to all the testers, translators and packagers, who help make Auralquiz better!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1133"/>
+        <location filename="../src/auralwindow.cpp" line="1098"/>
         <source>Auralquiz is licensed under the GNU GPL license.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1135"/>
+        <location filename="../src/auralwindow.cpp" line="1100"/>
         <source>Main screen image and some icons are based on Oxygen icons, under LGPL license.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1208"/>
+        <location filename="../src/auralwindow.cpp" line="1185"/>
         <source>Player %1 of %2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1373"/>
+        <location filename="../src/auralwindow.cpp" line="1351"/>
         <source>Go, %1!</source>
         <comment>%1=player&apos;s name</comment>
         <translation type="unfinished">Vai, %1!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1470"/>
+        <location filename="../src/auralwindow.cpp" line="1448"/>
         <source>%1 by %2</source>
         <comment>1=song title, 2=author name</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1475"/>
+        <location filename="../src/auralwindow.cpp" line="1453"/>
         <source>+%1 points!</source>
         <translation>+%1 punti!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1501"/>
+        <location filename="../src/auralwindow.cpp" line="1479"/>
         <source>Correct answer was:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1572"/>
+        <location filename="../src/auralwindow.cpp" line="1550"/>
         <source>End game?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1573"/>
+        <location filename="../src/auralwindow.cpp" line="1551"/>
         <source>Are you sure you want to end this game?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;Yes, end it</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1575"/>
+        <location filename="../src/auralwindow.cpp" line="1553"/>
         <source>&amp;No</source>
         <translation type="unfinished"></translation>
     </message>
@@ -247,94 +247,94 @@ Forse il tuo Phonon-backend non supporta i file in formato MP3.</translation>
         <translation>Primo utilizzo</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1319"/>
+        <location filename="../src/auralwindow.cpp" line="1297"/>
         <source>Not enough music files</source>
         <translation>Numero di file musicali insufficiente</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1320"/>
+        <location filename="../src/auralwindow.cpp" line="1298"/>
         <source>You don&apos;t have enough music files, or from enough different artists.
 You need music from at least 5 different artists to be able to generate questions.</source>
         <translation>Non hai abbastanza file musicali, o di abbastanza artisti diversi.
 Devi avere canzoni di almeno 5 artisti diversi per poter generare le domande.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1379"/>
+        <location filename="../src/auralwindow.cpp" line="1357"/>
         <source>Next!</source>
         <translation>Prossimo!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1454"/>
+        <location filename="../src/auralwindow.cpp" line="1432"/>
         <source>Correct!!</source>
         <translation>Corretto!!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1455"/>
+        <location filename="../src/auralwindow.cpp" line="1433"/>
         <source>Yeah!</source>
         <translation>Sì!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1456"/>
+        <location filename="../src/auralwindow.cpp" line="1434"/>
         <source>That&apos;s right!</source>
         <translation>È giusto!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1457"/>
+        <location filename="../src/auralwindow.cpp" line="1435"/>
         <source>Good!</source>
         <translation>Bene!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1458"/>
+        <location filename="../src/auralwindow.cpp" line="1436"/>
         <source>Great!</source>
         <translation>Grande!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1486"/>
+        <location filename="../src/auralwindow.cpp" line="1464"/>
         <source>Wrong!</source>
         <translation>Sbagliato!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1487"/>
+        <location filename="../src/auralwindow.cpp" line="1465"/>
         <source>No!</source>
         <translation>No!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1489"/>
+        <location filename="../src/auralwindow.cpp" line="1467"/>
         <source>Ooops!</source>
         <translation>Ops!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1490"/>
+        <location filename="../src/auralwindow.cpp" line="1468"/>
         <source>FAIL!</source>
         <translation>FALLITO!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1488"/>
+        <location filename="../src/auralwindow.cpp" line="1466"/>
         <source>That&apos;s not it.</source>
         <translation>Non è quello.</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1408"/>
+        <location filename="../src/auralwindow.cpp" line="1386"/>
         <source>All done!</source>
         <translation>Finito!</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="321"/>
+        <location filename="../src/auralwindow.cpp" line="278"/>
         <source>&amp;Options</source>
         <translation>&amp;Opzioni</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="427"/>
+        <location filename="../src/auralwindow.cpp" line="384"/>
         <source>Time</source>
         <translation>Tempo</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1198"/>
+        <location filename="../src/auralwindow.cpp" line="1172"/>
         <source>Who plays this song?</source>
         <translation>Chi canta questa canzone?</translation>
     </message>
     <message>
-        <location filename="../src/auralwindow.cpp" line="1202"/>
+        <location filename="../src/auralwindow.cpp" line="1176"/>
         <source>What&apos;s the title of this song?</source>
         <translation>Qual è il titolo di questa canzone?</translation>
     </message>
@@ -342,88 +342,100 @@ Devi avere canzoni di almeno 5 artisti diversi per poter generare le domande.</t
 <context>
     <name>MusicAnalyzer</name>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="125"/>
+        <location filename="../src/musicanalyzer.cpp" line="121"/>
         <source>Configure your music folder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="214"/>
+        <location filename="../src/musicanalyzer.cpp" line="216"/>
         <source>Analyzing music. Please wait</source>
         <translation type="unfinished">Analisi musica. Attendi</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="223"/>
-        <source>Getting list of files under
-%1</source>
-        <comment>%1 is a folder</comment>
+        <location filename="../src/musicanalyzer.cpp" line="226"/>
+        <source>Getting list of files under:</source>
+        <comment>A list of folders is shown below</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="227"/>
+        <location filename="../src/musicanalyzer.cpp" line="231"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="230"/>
+        <location filename="../src/musicanalyzer.cpp" line="234"/>
         <source>Listing files...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="255"/>
-        <location filename="../src/musicanalyzer.cpp" line="361"/>
+        <location filename="../src/musicanalyzer.cpp" line="274"/>
+        <location filename="../src/musicanalyzer.cpp" line="386"/>
         <source>Please reload music info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="256"/>
+        <location filename="../src/musicanalyzer.cpp" line="275"/>
         <source>Music analysis was cancelled</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="269"/>
+        <location filename="../src/musicanalyzer.cpp" line="288"/>
+        <source>There are no valid music files in your selected music folders.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="291"/>
+        <source>Please, select other folders containing Ogg, FLAC, Opus or MP3 files, and try again.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/musicanalyzer.cpp" line="312"/>
+        <source>Analyzing %1 files under:</source>
+        <comment>%1 is a number, and a folder list follows below</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
         <source>There are no valid music files in your selected music directory.</source>
-        <translation type="unfinished">Non ci sono file musicali validi nella cartella selezionata.</translation>
+        <translation type="obsolete">Non ci sono file musicali validi nella cartella selezionata.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="272"/>
         <source>Please, select another directory containing Ogg, FLAC or MP3 files, and try again.</source>
-        <translation type="unfinished">Seleziona un&apos;altra cartella contenente file Ogg, FLAC o MP3, e prova di nuovo.</translation>
+        <translation type="obsolete">Seleziona un&apos;altra cartella contenente file Ogg, FLAC o MP3, e prova di nuovo.</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="276"/>
+        <location filename="../src/musicanalyzer.cpp" line="295"/>
         <source>There is no music!</source>
         <translation type="unfinished">Musica non trovata!</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="280"/>
-        <location filename="../src/musicanalyzer.cpp" line="385"/>
+        <location filename="../src/musicanalyzer.cpp" line="299"/>
+        <location filename="../src/musicanalyzer.cpp" line="411"/>
         <source>Please choose another music folder</source>
         <translation type="unfinished">Scegli un&apos;altra cartella della musica</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="292"/>
         <source>Analyzing %1 files
 under %2</source>
         <comment>%1 is a number, %2 is a folder</comment>
-        <translation type="unfinished">Analisi %1 file in %2</translation>
+        <translation type="obsolete">Analisi %1 file in %2</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="297"/>
+        <location filename="../src/musicanalyzer.cpp" line="319"/>
         <source>Cancel analysis</source>
         <translation type="unfinished">Annulla analisi</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="300"/>
+        <location filename="../src/musicanalyzer.cpp" line="322"/>
         <source>Analyzing your music...</source>
         <translation type="unfinished">Analisi della tua musica...</translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="386"/>
+        <location filename="../src/musicanalyzer.cpp" line="412"/>
         <source>The folder you selected doesn&apos;t have enough valid music files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/musicanalyzer.cpp" line="396"/>
+        <location filename="../src/musicanalyzer.cpp" line="422"/>
         <source>&amp;Start game</source>
         <translation type="unfinished">Inizio &amp;gioco</translation>
     </message>
@@ -436,122 +448,147 @@ under %2</source>
         <translation>Opzioni gioco</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="59"/>
+        <location filename="../src/optionsdialog.cpp" line="62"/>
         <source>Using music from:</source>
         <translation>Usando la musica da:</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="64"/>
         <source>Select your &amp;music folder...</source>
-        <translation>Seleziona la tua cartella della &amp;musica...</translation>
+        <translation type="vanished">Seleziona la tua cartella della &amp;musica...</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="83"/>
+        <location filename="../src/optionsdialog.cpp" line="103"/>
         <source>&amp;Easier</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="98"/>
+        <location filename="../src/optionsdialog.cpp" line="117"/>
         <source>&amp;Harder</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="126"/>
+        <location filename="../src/optionsdialog.cpp" line="144"/>
         <source>How many &amp;questions?</source>
         <translation>Quante &amp;domande?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="131"/>
+        <location filename="../src/optionsdialog.cpp" line="149"/>
         <source>questions</source>
         <translation>domande</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="135"/>
+        <location filename="../src/optionsdialog.cpp" line="153"/>
         <source>How many &amp;players?</source>
         <translation>Quanti &amp;giocatori?</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="140"/>
+        <location filename="../src/optionsdialog.cpp" line="158"/>
         <source>players</source>
         <translation>giocatori</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="144"/>
+        <location filename="../src/optionsdialog.cpp" line="162"/>
         <source>Use own color theme</source>
         <translation>Usa tema dei colori proprio</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="209"/>
+        <location filename="../src/optionsdialog.cpp" line="227"/>
         <source>Player names</source>
         <translation>Nomi dei giocatori</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="225"/>
+        <location filename="../src/optionsdialog.cpp" line="243"/>
         <source>Save and &amp;reload music</source>
         <translation>Salva e &amp;ricarica la musica</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="363"/>
+        <location filename="../src/optionsdialog.cpp" line="406"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="407"/>
+        <source>Cannot enter selected folder:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="411"/>
+        <source>Please choose another one.</source>
+        <comment>As in: another folder</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="475"/>
         <source>In this level you&apos;ll have to type the answer.</source>
         <translation type="unfinished">In questo livello devi digitare la risposta.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="366"/>
+        <location filename="../src/optionsdialog.cpp" line="478"/>
         <source>It&apos;s not too strict, so you don&apos;t have to worry about caps, commas and such.</source>
         <translation type="unfinished">Non è molto stringente, quindi non ti devi preoccupare di maiuscole, virgole e simili.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="373"/>
+        <location filename="../src/optionsdialog.cpp" line="485"/>
         <source>In this level you&apos;ll have to click the correct button, or press the 1, 2, 3 and 4 keys in your keyboard.</source>
         <translation type="unfinished">In questo livello devi cliccare il pulsante corretto, o premere i tasti 1, 2, 3 e 4 sulla tastiera.</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="460"/>
+        <location filename="../src/optionsdialog.cpp" line="573"/>
         <source>&amp;Save options</source>
         <translation>&amp;Salva opzioni</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="234"/>
+        <location filename="../src/optionsdialog.cpp" line="252"/>
         <source>&amp;Cancel</source>
         <translation>&amp;Annulla</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="304"/>
+        <location filename="../src/optionsdialog.cpp" line="70"/>
+        <source>Add a music folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="76"/>
+        <source>Remove selected folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/optionsdialog.cpp" line="383"/>
         <source>Select where your music is located</source>
         <translation>Seleziona dove si trova la tua musica</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="351"/>
+        <location filename="../src/optionsdialog.cpp" line="463"/>
         <source>Piece of cake</source>
         <translation>Gioco da ragazzi</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="352"/>
+        <location filename="../src/optionsdialog.cpp" line="464"/>
         <source>Let&apos;s rock</source>
         <translation>Dacci dentro</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="353"/>
+        <location filename="../src/optionsdialog.cpp" line="465"/>
         <source>Come get some</source>
         <translation>Ti faccio nero</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="354"/>
+        <location filename="../src/optionsdialog.cpp" line="466"/>
         <source>Damn I&apos;m good</source>
         <translation>Ehi! Sono bravo</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="355"/>
+        <location filename="../src/optionsdialog.cpp" line="467"/>
         <source>HARD!!</source>
         <translation>DIFFICILE!!</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="356"/>
+        <location filename="../src/optionsdialog.cpp" line="468"/>
         <source>Hardcore! Type the answer</source>
         <translation>Estremo! Scrivi la risposta</translation>
     </message>
     <message>
-        <location filename="../src/optionsdialog.cpp" line="490"/>
+        <location filename="../src/optionsdialog.cpp" line="606"/>
         <source>Start!</source>
         <translation>Inizio!</translation>
     </message>
